#!/usr/bin/env python

__author__ = 'boulefi'

import sys
import os

sys.path.append("../gui")
sys.path.append("../")

import unittest
import gui.matplotlibwidgetFile

class TestFormEvents(unittest.TestCase):
    def SetUp(self):
        """

        """
        test = 1





#!/usr/bin/env python

import sys
from PyQt4 import QtGui
from matplotlib.backends.backend_qt4agg import FigureCanvasQTAgg as FigureCanvas
import scipy
from matplotlib.figure import Figure
import matplotlib.pyplot
from pylab import *
import seaborn as sns

import sys

sys.path.append('..')
sys.path.append('../gui')


class MplCanvas(FigureCanvas):
    """
    This function initializes the figure.
    Inputs : FigureCanvas : The canvas for the figure.
    """

    def __init__(self):
        self.fig = Figure()
        self.picture = self.fig.add_subplot(111)
        FigureCanvas.__init__(self, self.fig)

        self.x_data = []
        self.y_data = [[]]
        self.num_plot = 0

    def update_fields(self, x_data, y_data, num_plot):
        """
        This function updates data that we need to display curves, from "data_processing" of  "gui_mainLayout" file.
        Inputs : x_data : An array with wavelengths.
                 y_data : An array with curve's data.
                 num_plot : The line, curve to plot.
        """
        self.x_data = x_data
        self.y_data = y_data
        self.num_plot = num_plot

    def display_graphic(self, flag_curves, ui, grid):
        """
        This function plots results of a file into the canvas.
        Inputs : flag_curves : A boolean to know if we have to plot all curves or not.
                ui : The main_Window.
        """
        matplotlib.patches.Patch(linewidth=100)

        ui.graphic_widget.canvas.picture.clear()

        #print(self.x_data)


        x = scipy.linspace(self.x_data[0], self.x_data[-1], len(self.x_data))  # X-axis

        # Display grid
        if grid:
            ui.graphic_widget.canvas.picture.grid(True)

        curve_wanted = 0  # Iterator on lines of y_data
        for curve in self.y_data:
            if flag_curves:
                if curve_wanted == self.num_plot:  # If the iterator is equal of the slider's value,
                    # this curve is different.
                    ui.graphic_widget.canvas.picture.plot(x, curve, '-r',
                                                          label='Case : {0}/{1}'.format(str(curve_wanted + 1),
                                                                                        str(len(self.y_data))),
                                                          linewidth=4)
                else:
                    ui.graphic_widget.canvas.picture.plot(x, curve, '0.75')
            else:
                if curve_wanted == self.num_plot:
                    ui.graphic_widget.canvas.picture.plot(x, curve, '-r',
                                                          label='Case : {0}/{1}'.format(str(curve_wanted + 1),
                                                                                        str(len(self.y_data))))
            curve_wanted += 1

        ui.graphic_widget.canvas.picture.set_xlabel('Wavelength (${nm}$)')
        ui.graphic_widget.canvas.picture.set_ylabel('Reflectance ($Sr^{-1}$)')
        self.legend = ui.graphic_widget.canvas.picture.legend()  # Display in a legend curves's labels.
        ui.graphic_widget.canvas.picture.legend(bbox_to_anchor=(1.1, 1.05))

        ui.graphic_widget.canvas.draw()


class matplotlibWidget(QtGui.QWidget):
    """
    This function initializes the place where the figure will be display.
    """

    def __init__(self, parent=None):
        QtGui.QWidget.__init__(self, parent)
        self.canvas = MplCanvas()
        self.vbl = QtGui.QVBoxLayout()
        self.vbl.addWidget(self.canvas)
        self.setLayout(self.vbl)


#!/usr/bin/env python

__author__ = 'boulefi'

import sys
import os
import unittest

sys.path.append("../gui")
sys.path.append("../")


import gui
from gui.gui_mainLayout import *

class TestFormEvents(unittest.TestCase):
    """

    """
    def setUp(self):
        """

        """
        self.batch_name_value = "batch_name_test"
        self.p_values = "10, 11, 12"
        self.x_value = "1"
        self.y_value = "2"
        self.g_value = "3"
        self.s_value = "4"
        self.z_value = "5"
        self.wavelength_values = "6, 7, 8, 9"
        self.verbose_value = "2"
        self.phyto_path = "gui/file_phyto"
        self.bottom_path = "gui/file_bottom"
        self.exec_path = "gui/file_exec"
        self.nb_cpu = "1"
        self.report_parameter_value = "Rrs"
        self.saa_values = '10'
        self.sza_values = '11'

    def test_data(self):
        """
        The following will check if all data filled are get back well.
        """
        self.FE = gui.gui_mainLayout.FormEvents()
        self.ui = self.FE.ui

        # self.ui.batch_name_value.setText(self.batch_name_value)
        # self.ui.p_values.setText(self.p_values)
        # self.ui.x_value.setText(self.x_value)
        # self.ui.y_value.setText(self.y_value)
        # self.ui.g_value.setText(self.g_value)
        # self.ui.s_value.setText(self.s_value)
        # self.ui.z_value.setText(self.z_value)
        # self.ui.wavelength_values.setText(self.wavelength_values)
        # self.ui.verbose_value.setText(self.verbose_value)
        # self.ui.phyto_path.setText(self.phyto_path)
        # self.ui.bottom_path.setText(self.bottom_path)
        # self.ui.exec_path.setText(self.exec_path)
        # self.ui.nb_cpu.itemText(self.nb_cpu)
        # self.ui.report_parameter_value.setText(self.report_parameter_value)
        # self.ui.saa_values.text(self.saa_values)
        # self.ui.sza_values.text(self.sza_values)

        data = self.FE.data()

        self.assertEqual(self.batch_name_value, data.batch_name_value)
        self.assertEqual(self.p_values, data.p_values)
        self.assertEqual(self.x_value, data.x_value)
        self.assertEqual(self.y_value, data.y_value)
        self.assertEqual(self.g_value, data.g_value)
        self.assertEqual(self.s_value, data.s_value)
        self.assertEqual(self.z_value, data.z_value)
        self.assertEqual(self.wavelength_values, data.wavelength_values)
        self.assertEqual(self.verbose_value, data.verbose_value)
        self.assertEqual(self.phyto_path, data.phyto_path)
        self.assertEqual(self.bottom_path, data.bottom_path)
        self.assertEqual(self.exec_path, data.exec_path)
        self.assertEqual(self.nb_cpu, data.nb_cpu)
        self.assertEqual(self.report_parameter_value, data.report_parameter_value)
        self.assertEqual(self.saa_values, data.saa_values)
        self.assertEqual(self.sza_values, data.sza_values)

    def test_search_directory_exec_path(self):
        """
        The following will check if the fileDialog for the directory works well.
        """
        # self.ui = gui.gui_Layout.Ui_MainWindow()
        # self.FE.search_directory_exec_path()
        essai = 1

    def test_search_file_phyto(self):
        """
        The following will check if the the fileDialog for the file about phytoplankton works well.
        """
        test = 1

    def test_search_file_bottom(self):
        """
        The following will check if the the fileDialog for the file about the bottom works well.
        """
        test = 1

    def test_search_file_result(self):
        """

        """
        #self.ui = Ui_MainWindow()
        #self.ui.tabWidget.currentIndex(gui.gui_mainLayout.TabWidget.NORMAL_MODE)

    def test_check_values(self):
        """
        The following will check if all values given are the good case, are writen by the good way.
        """
        test = 1

    def test_write_to_file(self):
        """
        The following will checks if "gui_batch.py" is called with data
        and use one of its function to write the batch file.
        """
        test = 1

    def test_display_graphic(self):
        """
        The following will test if the results are plotted correctly.
        """
        test = 1

    def test_graphic_slider(nb_case):
        """
        The following will test if the slider under the graphic has the good values to display curves.
        """
        test = 1

    def test_display_error_message(self):
        """
        The following will check if the error message is well displayed.
        """
        test = 1

    def test_hide_error_message(self):
        """
        The following will check if the error message is well remove.
        """
        test = 1

    def test_execute_planarrad(self):
        """
        The following will check if planarRad is execute only if there is no errors.
        """
        test = 1

    def test_progress_bar(self):
        """
        The following will verify if the progress bar works and go through default values.
        """
        test = 1

    def test_cancel_planarrad(self):
        """
        The following will test if the cancel button stop planarRad.
        """
        test = 1

    def test_save_figure(self):
        """
        The following will check if the button to save the figure of the graphic works.
        """
        test = 1

def main():
    unittest.main()


if __name__ == '__main__':
    main()



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'logReader.ui'
#
# Created: Mon Jun  8 12:27:17 2015
#      by: PyQt4 UI code generator 4.11.3
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    def _fromUtf8(s):
        return s

try:
    _encoding = QtGui.QApplication.UnicodeUTF8
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig, _encoding)
except AttributeError:
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig)

class Ui_win_log_reader(object):
    def setupUi(self, win_log_reader):
        win_log_reader.setObjectName(_fromUtf8("win_log_reader"))
        win_log_reader.setWindowModality(QtCore.Qt.WindowModal)
        win_log_reader.resize(1200, 500)
        win_log_reader.setModal(True)
        self.scrollArea = QtGui.QScrollArea(win_log_reader)
        self.scrollArea.setGeometry(QtCore.QRect(10, 10, 1181, 411))
        self.scrollArea.setWidgetResizable(True)
        self.scrollArea.setObjectName(_fromUtf8("scrollArea"))
        self.scrollAreaWidgetContents = QtGui.QWidget()
        self.scrollAreaWidgetContents.setGeometry(QtCore.QRect(0, 0, 1179, 409))
        self.scrollAreaWidgetContents.setObjectName(_fromUtf8("scrollAreaWidgetContents"))
        self.textEdit = QtGui.QTextEdit(self.scrollAreaWidgetContents)
        self.textEdit.setGeometry(QtCore.QRect(0, 0, 1181, 411))
        self.textEdit.setVerticalScrollBarPolicy(QtCore.Qt.ScrollBarAsNeeded)
        self.textEdit.setAutoFormatting(QtGui.QTextEdit.AutoAll)
        self.textEdit.setReadOnly(True)
        self.textEdit.setObjectName(_fromUtf8("textEdit"))
        self.scrollArea.setWidget(self.scrollAreaWidgetContents)
        self.btn_close = QtGui.QPushButton(win_log_reader)
        self.btn_close.setGeometry(QtCore.QRect(1070, 440, 98, 27))
        self.btn_close.setToolTip(_fromUtf8(""))
        self.btn_close.setObjectName(_fromUtf8("btn_close"))
        self.btn_clearErrorLog = QtGui.QPushButton(win_log_reader)
        self.btn_clearErrorLog.setGeometry(QtCore.QRect(960, 440, 98, 27))
        self.btn_clearErrorLog.setToolTip(_fromUtf8(""))
        self.btn_clearErrorLog.setObjectName(_fromUtf8("btn_clearErrorLog"))

        self.retranslateUi(win_log_reader)
        QtCore.QObject.connect(self.btn_clearErrorLog, QtCore.SIGNAL(_fromUtf8("clicked()")), self.textEdit.clear)
        QtCore.QMetaObject.connectSlotsByName(win_log_reader)

    def retranslateUi(self, win_log_reader):
        win_log_reader.setWindowTitle(_translate("win_log_reader", "Processing Log", None))
        self.btn_close.setText(_translate("win_log_reader", "Close", None))
        self.btn_clearErrorLog.setText(_translate("win_log_reader", "Clear", None))
        self.btn_clearErrorLog.setShortcut(_translate("win_log_reader", "Ctrl+C", None))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'aboutGui.ui'
#
# Created: Mon Jun  8 12:27:16 2015
#      by: PyQt4 UI code generator 4.11.3
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    def _fromUtf8(s):
        return s

try:
    _encoding = QtGui.QApplication.UnicodeUTF8
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig, _encoding)
except AttributeError:
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig)

class Ui_win_about(object):
    def setupUi(self, win_about):
        win_about.setObjectName(_fromUtf8("win_about"))
        win_about.resize(589, 474)
        self.buttonBox = QtGui.QDialogButtonBox(win_about)
        self.buttonBox.setGeometry(QtCore.QRect(230, 430, 341, 32))
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Close)
        self.buttonBox.setObjectName(_fromUtf8("buttonBox"))
        self.label = QtGui.QLabel(win_about)
        self.label.setGeometry(QtCore.QRect(250, 20, 101, 91))
        self.label.setPixmap(QtGui.QPixmap(_fromUtf8("../../../../../../../opt/extras.ubuntu.com/pymi/icons/pymi.png")))
        self.label.setScaledContents(True)
        self.label.setObjectName(_fromUtf8("label"))
        self.label_2 = QtGui.QLabel(win_about)
        self.label_2.setGeometry(QtCore.QRect(200, 130, 171, 41))
        self.label_2.setObjectName(_fromUtf8("label_2"))
        self.label_3 = QtGui.QLabel(win_about)
        self.label_3.setGeometry(QtCore.QRect(20, 190, 551, 231))
        self.label_3.setMaximumSize(QtCore.QSize(551, 16777215))
        self.label_3.setScaledContents(True)
        self.label_3.setWordWrap(True)
        self.label_3.setObjectName(_fromUtf8("label_3"))

        self.retranslateUi(win_about)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("accepted()")), win_about.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("rejected()")), win_about.reject)
        QtCore.QMetaObject.connectSlotsByName(win_about)

    def retranslateUi(self, win_about):
        win_about.setWindowTitle(_translate("win_about", "About Planarradpy", None))
        self.label_2.setText(_translate("win_about", "<html><head/><body><p><span style=\" font-size:22pt; font-weight:600;\">Planarradpy 0.1</span></p></body></html>", None))
        self.label_3.setText(_translate("win_about", "<html><head/><body><p align=\"justify\"><span style=\" font-family:\'Ubuntu,Ubuntu Beta,UbuntuBeta,Ubuntu,Bitstream Vera Sans,DejaVu Sans,Tahoma,sans-serif\'; font-size:14px; color:#333333; background-color:#ffffff;\">Planarradpy is a wrapper tool desgined for batch processing </span><a href=\"http://www.planarrad.com\"><span style=\" text-decoration: underline; color:#0000ff;\">Planarrad</span></a><span style=\" font-family:\'Ubuntu,Ubuntu Beta,UbuntuBeta,Ubuntu,Bitstream Vera Sans,DejaVu Sans,Tahoma,sans-serif\'; font-size:14px; color:#333333; background-color:#ffffff;\"> based on varying IOPs and visualising the outputs.</span></p><p align=\"justify\"><span style=\" font-family:\'Ubuntu,Ubuntu Beta,UbuntuBeta,Ubuntu,Bitstream Vera Sans,DejaVu Sans,Tahoma,sans-serif\'; font-size:14px; color:#333333; background-color:#ffffff;\">Licence : GNU GPL v 3</span></p><p><span style=\" font-family:\'Ubuntu,Ubuntu Beta,UbuntuBeta,Ubuntu,Bitstream Vera Sans,DejaVu Sans,Tahoma,sans-serif\'; font-size:14px; color:#333333; background-color:#ffffff;\">Authors : </span><a href=\"https://launchpad.net/~marrabld\"><span style=\" text-decoration: underline; color:#0000ff;\">Dan Marrable</span></a></p><p><span style=\" font-family:\'Ubuntu,Ubuntu Beta,UbuntuBeta,Ubuntu,Bitstream Vera Sans,DejaVu Sans,Tahoma,sans-serif\'; font-size:14px; color:#333333; background-color:#ffffff;\">Contributors : Frederic Boule, Anders Knudby </span></p><p><span style=\" font-family:\'Ubuntu,Ubuntu Beta,UbuntuBeta,Ubuntu,Bitstream Vera Sans,DejaVu Sans,Tahoma,sans-serif\'; font-size:14px; color:#333333; background-color:#ffffff;\">Website : </span><a href=\"https://marrabld.github.io/planarradpy/\"><span style=\" text-decoration: underline; color:#0000ff;\">Planarradpy</span></a></p><p><br/></p></body></html>", None))




__author__ = 'marrabld'

import os
print(os.getcwd())
os.chdir(os.path.join(os.getcwd(),  '../libplanarradpy'))

import libplanarradpy.planrad as pr

rt = pr.ReportTools()

#rep_dict = rt.read_pr_report('/home/marrabld/Desktop/rod_test/nadir/SAA262.39_SZA45.28_P0.01_X0.001_Y1.0_G0.01_S0.015_Z0.5/report.txt')

print(rt.write_batch_report('/home/marrabld/Desktop/rod_test/rod_Refl_BenthicMixture_1/', 'rrs'))


__author__ = 'marrabld'

import ConfigParser
import os


class State():
    def __init__(self):
        self.debug = ''

        conf = ConfigParser.ConfigParser()
        conf.read(os.path.join(os.path.dirname(__file__), 'planarradpy.conf'))
        self.debug = conf.get('Debug', 'Level')






__author__ = 'marrabld'

import libplanarradpy.planrad as pr

a = pr.RunParameters()
a.write_run_parameters_to_file()
a.write_sky_params_to_file()
a.write_surf_params_to_file()
a.write_phase_params_to_file()
a.exec_path = '/home/boulefi/jude2_install/bin'
a.verbose = 2

b = pr.BatchRun(a)
b.run()


# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'gui_Layout.ui'
#
# Created: Wed May 21 12:35:11 2014
#      by: PyQt4 UI code generator 4.9.3
#
# WARNING! All changes made in this file will be lost!




__author__ = 'marrabld'

import sys
import scipy

sys.path.append("../..")
sys.path.append("../")

import unittest
import libplanarradpy.planrad as pr


class TestPlanarrad(unittest.TestCase):
    def setUp(self):
        pass

    def test_main(self):
        pass

    def test_parse_input_file(self):
        input_file = '../inputs/batch_files/batch.txt'
        input_parameters = pr.FileTools.read_param_file_to_dict(input_file)
        pr.lg.info(input_parameters)

        rp = pr.RunParameters()
        rp.exec_path = input_parameters['exec_path']#'/home/marrabld/Apps/planarRad/bin'
        rp.verbose = input_parameters['verbose']
        rp.num_cpus = int(input_parameters['num_cpus'])
        rp.phytoplankton_absorption_file = input_parameters['phytoplankton_absorption_file']
        rp.bottom_reflectance_file = input_parameters['phytoplankton_absorption_file']

        p_list = pr.HelperMethods.string_to_float_list(input_parameters['p_list'])  # map(float, input_parameters['p_list'])
        x_list = pr.HelperMethods.string_to_float_list(input_parameters['x_list'])
        y_list = pr.HelperMethods.string_to_float_list(input_parameters['y_list'])
        g_list = pr.HelperMethods.string_to_float_list(input_parameters['g_list'])
        s_list = pr.HelperMethods.string_to_float_list(input_parameters['s_list'])
        z_list = pr.HelperMethods.string_to_float_list(input_parameters['z_list'])

        batch_name = input_parameters['batch_name']

        br = pr.BatchRun(rp, batch_name)
        br.batch_parameters(p_list,
                            x_list,
                            y_list,
                            g_list,
                            s_list,
                            z_list)

        br.generate_directories()
        #br.run()




#! /usr/bin/env python

__author__ = 'marrabld'

import os
#print(os.getcwd())
#os.chdir(os.path.join(os.getcwd(),  'libplanarradpy'))
import subprocess
import getopt
import sys
import libplanarradpy.planrad as pr

#sys.path.append("../")


def main(argv):
    input_file = ''
    output_file = ''
    try:
        opts, args = getopt.getopt(argv, "hi:o:", ["ifile=", "ofile="])
    except getopt.GetoptError:
        print('Launching GUI')
        p = subprocess.Popen("./gui/gui_mainLayout.py", shell=True)
        sys.exit(2)

    for opt, arg in opts:
        if opt == '-h':
            print('planarrad.py -i <input_file> -o <output_file>')
            sys.exit()
        elif opt in ("-i", "--ifile"):
            input_file = arg
        elif opt in ("-o", "--ofile"):
            output_file = arg
        elif opt in ("-g", "--gui"):
            print('Launching GUI -g')
            p = subprocess.Popen("./gui/gui_mainLayout.py")
            sys.exit()

    #print('Input file is :: ', input_file)
    #print('Report file is :: ', output_file)

    input_parameters = pr.FileTools.read_param_file_to_dict(input_file)
    #--------------------------------------------------#
    # build the required objects
    #--------------------------------------------------#
    rp = pr.RunParameters(input_parameters['wavelengths'])
    rp.verbose = input_parameters['verbose']
    rp.num_cpus = int(input_parameters['num_cpus'])
    rp.exec_path = input_parameters['exec_path']
    rp.phytoplankton_absorption_file = input_parameters['phytoplankton_absorption_file']
    rp.bottom_reflectance_file = input_parameters['bottom_reflectance_file']

    #--------------------------------------------------#
    # update the file names ?
    #--------------------------------------------------#

    #--------------------------------------------------#
    # rebuild the iop files ?
    #--------------------------------------------------#
    saa_list = pr.HelperMethods.string_to_float_list(input_parameters['saa_list'])
    sza_list = pr.HelperMethods.string_to_float_list(input_parameters['sza_list'])
    p_list = pr.HelperMethods.string_to_float_list(input_parameters['p_list'])
    x_list = pr.HelperMethods.string_to_float_list(input_parameters['x_list'])
    y_list = pr.HelperMethods.string_to_float_list(input_parameters['y_list'])
    g_list = pr.HelperMethods.string_to_float_list(input_parameters['g_list'])
    s_list = pr.HelperMethods.string_to_float_list(input_parameters['s_list'])
    z_list = pr.HelperMethods.string_to_float_list(input_parameters['z_list'])

    batch_name = input_parameters['batch_name']

    br = pr.BatchRun(rp, batch_name)
    br.batch_parameters(saa_list,
                        sza_list,
                        p_list,
                        x_list,
                        y_list,
                        g_list,
                        s_list,
                        z_list)

    br.generate_directories()
    br.run()

    rt = pr.ReportTools()
    rt.write_batch_report(os.path.abspath(os.path.join('./outputs', batch_name)), input_parameters['report_parameter'])


if __name__ == "__main__":
    main(sys.argv[1:])





# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'gui_Layout.ui'
#
# Created: Mon Jun  8 12:27:16 2015
#      by: PyQt4 UI code generator 4.11.3
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    def _fromUtf8(s):
        return s

try:
    _encoding = QtGui.QApplication.UnicodeUTF8
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig, _encoding)
except AttributeError:
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig)

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName(_fromUtf8("MainWindow"))
        MainWindow.setEnabled(True)
        MainWindow.resize(1362, 958)
        MainWindow.setAnimated(True)
        self.centralwidget = QtGui.QWidget(MainWindow)
        self.centralwidget.setEnabled(True)
        self.centralwidget.setObjectName(_fromUtf8("centralwidget"))
        self.run = QtGui.QPushButton(self.centralwidget)
        self.run.setGeometry(QtCore.QRect(19, 790, 101, 31))
        self.run.setObjectName(_fromUtf8("run"))
        self.tabWidget = QtGui.QTabWidget(self.centralwidget)
        self.tabWidget.setEnabled(True)
        self.tabWidget.setGeometry(QtCore.QRect(0, 1, 1371, 781))
        self.tabWidget.setBaseSize(QtCore.QSize(0, 0))
        font = QtGui.QFont()
        font.setItalic(False)
        font.setUnderline(False)
        self.tabWidget.setFont(font)
        self.tabWidget.setCursor(QtGui.QCursor(QtCore.Qt.ArrowCursor))
        self.tabWidget.setStyleSheet(_fromUtf8(""))
        self.tabWidget.setTabShape(QtGui.QTabWidget.Rounded)
        self.tabWidget.setElideMode(QtCore.Qt.ElideNone)
        self.tabWidget.setObjectName(_fromUtf8("tabWidget"))
        self.rad_transf_model_tab = QtGui.QWidget()
        self.rad_transf_model_tab.setObjectName(_fromUtf8("rad_transf_model_tab"))
        self.p_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.p_label.setGeometry(QtCore.QRect(20, 130, 71, 21))
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.p_label.sizePolicy().hasHeightForWidth())
        self.p_label.setSizePolicy(sizePolicy)
        self.p_label.setObjectName(_fromUtf8("p_label"))
        self.execPath_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.execPath_label.setGeometry(QtCore.QRect(20, 686, 121, 20))
        self.execPath_label.setObjectName(_fromUtf8("execPath_label"))
        self.cpu_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.cpu_label.setGeometry(QtCore.QRect(20, 645, 111, 21))
        self.cpu_label.setObjectName(_fromUtf8("cpu_label"))
        self.nb_cpu = QtGui.QComboBox(self.rad_transf_model_tab)
        self.nb_cpu.setGeometry(QtCore.QRect(160, 640, 71, 31))
        self.nb_cpu.setObjectName(_fromUtf8("nb_cpu"))
        self.sens = QtGui.QSlider(self.rad_transf_model_tab)
        self.sens.setEnabled(True)
        self.sens.setGeometry(QtCore.QRect(630, 370, 721, 31))
        self.sens.setCursor(QtGui.QCursor(QtCore.Qt.ArrowCursor))
        self.sens.setFocusPolicy(QtCore.Qt.NoFocus)
        self.sens.setAutoFillBackground(False)
        self.sens.setOrientation(QtCore.Qt.Horizontal)
        self.sens.setObjectName(_fromUtf8("sens"))
        self.label_17 = QtGui.QLabel(self.rad_transf_model_tab)
        self.label_17.setGeometry(QtCore.QRect(580, 380, 41, 16))
        self.label_17.setObjectName(_fromUtf8("label_17"))
        self.line = QtGui.QFrame(self.rad_transf_model_tab)
        self.line.setEnabled(True)
        self.line.setGeometry(QtCore.QRect(560, 20, 20, 701))
        self.line.setAutoFillBackground(False)
        self.line.setFrameShape(QtGui.QFrame.VLine)
        self.line.setFrameShadow(QtGui.QFrame.Sunken)
        self.line.setObjectName(_fromUtf8("line"))
        self.exec_path = QtGui.QLineEdit(self.rad_transf_model_tab)
        self.exec_path.setEnabled(False)
        self.exec_path.setGeometry(QtCore.QRect(40, 720, 481, 21))
        self.exec_path.setObjectName(_fromUtf8("exec_path"))
        self.p_values = QtGui.QLineEdit(self.rad_transf_model_tab)
        self.p_values.setGeometry(QtCore.QRect(120, 130, 401, 21))
        self.p_values.setObjectName(_fromUtf8("p_values"))
        self.title_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.title_label.setGeometry(QtCore.QRect(20, 0, 361, 31))
        self.title_label.setObjectName(_fromUtf8("title_label"))
        self.particles_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.particles_label.setGeometry(QtCore.QRect(20, 155, 121, 21))
        self.particles_label.setObjectName(_fromUtf8("particles_label"))
        self.x_value = QtGui.QLineEdit(self.rad_transf_model_tab)
        self.x_value.setGeometry(QtCore.QRect(120, 180, 401, 21))
        self.x_value.setObjectName(_fromUtf8("x_value"))
        self.y_value = QtGui.QLineEdit(self.rad_transf_model_tab)
        self.y_value.setGeometry(QtCore.QRect(120, 210, 401, 21))
        self.y_value.setObjectName(_fromUtf8("y_value"))
        self.x_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.x_label.setGeometry(QtCore.QRect(75, 180, 21, 21))
        self.x_label.setObjectName(_fromUtf8("x_label"))
        self.y_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.y_label.setGeometry(QtCore.QRect(75, 210, 21, 21))
        self.y_label.setObjectName(_fromUtf8("y_label"))
        self.organic_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.organic_label.setGeometry(QtCore.QRect(20, 235, 131, 21))
        self.organic_label.setObjectName(_fromUtf8("organic_label"))
        self.s_value = QtGui.QLineEdit(self.rad_transf_model_tab)
        self.s_value.setGeometry(QtCore.QRect(120, 290, 401, 21))
        self.s_value.setObjectName(_fromUtf8("s_value"))
        self.g_value = QtGui.QLineEdit(self.rad_transf_model_tab)
        self.g_value.setGeometry(QtCore.QRect(120, 260, 401, 21))
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.g_value.sizePolicy().hasHeightForWidth())
        self.g_value.setSizePolicy(sizePolicy)
        self.g_value.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.g_value.setObjectName(_fromUtf8("g_value"))
        self.g_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.g_label.setGeometry(QtCore.QRect(73, 260, 21, 21))
        self.g_label.setObjectName(_fromUtf8("g_label"))
        self.s_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.s_label.setGeometry(QtCore.QRect(76, 290, 21, 21))
        self.s_label.setObjectName(_fromUtf8("s_label"))
        self.z_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.z_label.setGeometry(QtCore.QRect(20, 320, 71, 21))
        self.z_label.setObjectName(_fromUtf8("z_label"))
        self.z_value = QtGui.QLineEdit(self.rad_transf_model_tab)
        self.z_value.setGeometry(QtCore.QRect(120, 320, 401, 21))
        self.z_value.setObjectName(_fromUtf8("z_value"))
        self.label_10 = QtGui.QLabel(self.rad_transf_model_tab)
        self.label_10.setGeometry(QtCore.QRect(530, 320, 21, 21))
        self.label_10.setObjectName(_fromUtf8("label_10"))
        self.exec_path_button = QtGui.QPushButton(self.rad_transf_model_tab)
        self.exec_path_button.setGeometry(QtCore.QRect(160, 680, 71, 31))
        self.exec_path_button.setObjectName(_fromUtf8("exec_path_button"))
        self.waveL_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.waveL_label.setGeometry(QtCore.QRect(20, 350, 101, 21))
        self.waveL_label.setObjectName(_fromUtf8("waveL_label"))
        self.wavelength_values = QtGui.QLineEdit(self.rad_transf_model_tab)
        self.wavelength_values.setGeometry(QtCore.QRect(120, 350, 401, 21))
        self.wavelength_values.setObjectName(_fromUtf8("wavelength_values"))
        self.phyto_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.phyto_label.setGeometry(QtCore.QRect(20, 475, 191, 21))
        self.phyto_label.setTextFormat(QtCore.Qt.AutoText)
        self.phyto_label.setObjectName(_fromUtf8("phyto_label"))
        self.phyto_button = QtGui.QPushButton(self.rad_transf_model_tab)
        self.phyto_button.setGeometry(QtCore.QRect(220, 470, 71, 31))
        self.phyto_button.setObjectName(_fromUtf8("phyto_button"))
        self.phyto_path = QtGui.QLineEdit(self.rad_transf_model_tab)
        self.phyto_path.setEnabled(False)
        self.phyto_path.setGeometry(QtCore.QRect(30, 510, 491, 21))
        self.phyto_path.setObjectName(_fromUtf8("phyto_path"))
        self.bottom_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.bottom_label.setGeometry(QtCore.QRect(20, 405, 141, 21))
        self.bottom_label.setObjectName(_fromUtf8("bottom_label"))
        self.bottom_path = QtGui.QLineEdit(self.rad_transf_model_tab)
        self.bottom_path.setEnabled(False)
        self.bottom_path.setGeometry(QtCore.QRect(30, 440, 491, 21))
        self.bottom_path.setObjectName(_fromUtf8("bottom_path"))
        self.bottom_button = QtGui.QPushButton(self.rad_transf_model_tab)
        self.bottom_button.setGeometry(QtCore.QRect(220, 400, 71, 31))
        self.bottom_button.setObjectName(_fromUtf8("bottom_button"))
        self.verbose_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.verbose_label.setGeometry(QtCore.QRect(20, 610, 66, 21))
        self.verbose_label.setObjectName(_fromUtf8("verbose_label"))
        self.verbose_value = QtGui.QLineEdit(self.rad_transf_model_tab)
        self.verbose_value.setGeometry(QtCore.QRect(160, 610, 71, 21))
        self.verbose_value.setObjectName(_fromUtf8("verbose_value"))
        self.label_14 = QtGui.QLabel(self.rad_transf_model_tab)
        self.label_14.setGeometry(QtCore.QRect(530, 350, 31, 21))
        self.label_14.setObjectName(_fromUtf8("label_14"))
        self.label_31 = QtGui.QLabel(self.rad_transf_model_tab)
        self.label_31.setGeometry(QtCore.QRect(240, 610, 51, 16))
        self.label_31.setObjectName(_fromUtf8("label_31"))
        self.label_32 = QtGui.QLabel(self.rad_transf_model_tab)
        self.label_32.setGeometry(QtCore.QRect(240, 650, 131, 16))
        self.label_32.setObjectName(_fromUtf8("label_32"))
        self.graphicsView_3 = QtGui.QGraphicsView(self.rad_transf_model_tab)
        self.graphicsView_3.setGeometry(QtCore.QRect(580, 10, 771, 351))
        self.graphicsView_3.setObjectName(_fromUtf8("graphicsView_3"))
        self.graphic_widget = matplotlibWidget(self.rad_transf_model_tab)
        self.graphic_widget.setGeometry(QtCore.QRect(570, 0, 791, 371))
        self.graphic_widget.setObjectName(_fromUtf8("graphic_widget"))
        self.line_3 = QtGui.QFrame(self.rad_transf_model_tab)
        self.line_3.setGeometry(QtCore.QRect(830, 410, 20, 311))
        self.line_3.setFrameShape(QtGui.QFrame.VLine)
        self.line_3.setFrameShadow(QtGui.QFrame.Sunken)
        self.line_3.setObjectName(_fromUtf8("line_3"))
        self.label = QtGui.QLabel(self.rad_transf_model_tab)
        self.label.setGeometry(QtCore.QRect(580, 410, 141, 17))
        self.label.setObjectName(_fromUtf8("label"))
        self.label_2 = QtGui.QLabel(self.rad_transf_model_tab)
        self.label_2.setGeometry(QtCore.QRect(870, 410, 171, 17))
        self.label_2.setObjectName(_fromUtf8("label_2"))
        self.column1_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.column1_label.setGeometry(QtCore.QRect(890, 440, 131, 21))
        self.column1_label.setText(_fromUtf8(""))
        self.column1_label.setObjectName(_fromUtf8("column1_label"))
        self.column2_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.column2_label.setGeometry(QtCore.QRect(890, 470, 131, 21))
        self.column2_label.setText(_fromUtf8(""))
        self.column2_label.setObjectName(_fromUtf8("column2_label"))
        self.column1_result = QtGui.QLabel(self.rad_transf_model_tab)
        self.column1_result.setGeometry(QtCore.QRect(1030, 440, 41, 17))
        self.column1_result.setText(_fromUtf8(""))
        self.column1_result.setObjectName(_fromUtf8("column1_result"))
        self.column2_result = QtGui.QLabel(self.rad_transf_model_tab)
        self.column2_result.setGeometry(QtCore.QRect(1030, 470, 41, 17))
        self.column2_result.setText(_fromUtf8(""))
        self.column2_result.setObjectName(_fromUtf8("column2_result"))
        self.show_all_curves = QtGui.QCheckBox(self.rad_transf_model_tab)
        self.show_all_curves.setGeometry(QtCore.QRect(600, 440, 131, 22))
        self.show_all_curves.setObjectName(_fromUtf8("show_all_curves"))
        self.column3_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.column3_label.setGeometry(QtCore.QRect(890, 500, 131, 16))
        self.column3_label.setText(_fromUtf8(""))
        self.column3_label.setObjectName(_fromUtf8("column3_label"))
        self.column5_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.column5_label.setGeometry(QtCore.QRect(890, 560, 131, 16))
        self.column5_label.setText(_fromUtf8(""))
        self.column5_label.setObjectName(_fromUtf8("column5_label"))
        self.column6_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.column6_label.setGeometry(QtCore.QRect(890, 590, 131, 16))
        self.column6_label.setText(_fromUtf8(""))
        self.column6_label.setObjectName(_fromUtf8("column6_label"))
        self.column7_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.column7_label.setGeometry(QtCore.QRect(890, 620, 131, 16))
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.column7_label.setFont(font)
        self.column7_label.setText(_fromUtf8(""))
        self.column7_label.setObjectName(_fromUtf8("column7_label"))
        self.column8_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.column8_label.setGeometry(QtCore.QRect(890, 650, 131, 16))
        self.column8_label.setText(_fromUtf8(""))
        self.column8_label.setObjectName(_fromUtf8("column8_label"))
        self.column3_result = QtGui.QLabel(self.rad_transf_model_tab)
        self.column3_result.setGeometry(QtCore.QRect(1030, 500, 41, 17))
        self.column3_result.setText(_fromUtf8(""))
        self.column3_result.setObjectName(_fromUtf8("column3_result"))
        self.column4_result = QtGui.QLabel(self.rad_transf_model_tab)
        self.column4_result.setGeometry(QtCore.QRect(1030, 530, 41, 17))
        self.column4_result.setText(_fromUtf8(""))
        self.column4_result.setObjectName(_fromUtf8("column4_result"))
        self.column5_result = QtGui.QLabel(self.rad_transf_model_tab)
        self.column5_result.setGeometry(QtCore.QRect(1030, 560, 41, 17))
        self.column5_result.setText(_fromUtf8(""))
        self.column5_result.setObjectName(_fromUtf8("column5_result"))
        self.column6_result = QtGui.QLabel(self.rad_transf_model_tab)
        self.column6_result.setGeometry(QtCore.QRect(1030, 590, 41, 17))
        self.column6_result.setText(_fromUtf8(""))
        self.column6_result.setObjectName(_fromUtf8("column6_result"))
        self.column7_result = QtGui.QLabel(self.rad_transf_model_tab)
        self.column7_result.setGeometry(QtCore.QRect(1030, 620, 41, 17))
        self.column7_result.setText(_fromUtf8(""))
        self.column7_result.setObjectName(_fromUtf8("column7_result"))
        self.column8_result = QtGui.QLabel(self.rad_transf_model_tab)
        self.column8_result.setGeometry(QtCore.QRect(1030, 650, 41, 17))
        self.column8_result.setText(_fromUtf8(""))
        self.column8_result.setObjectName(_fromUtf8("column8_result"))
        self.column4_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.column4_label.setGeometry(QtCore.QRect(890, 530, 131, 20))
        self.column4_label.setText(_fromUtf8(""))
        self.column4_label.setObjectName(_fromUtf8("column4_label"))
        self.line_4 = QtGui.QFrame(self.rad_transf_model_tab)
        self.line_4.setGeometry(QtCore.QRect(60, 380, 421, 21))
        self.line_4.setFrameShape(QtGui.QFrame.HLine)
        self.line_4.setFrameShadow(QtGui.QFrame.Sunken)
        self.line_4.setObjectName(_fromUtf8("line_4"))
        self.line_5 = QtGui.QFrame(self.rad_transf_model_tab)
        self.line_5.setGeometry(QtCore.QRect(60, 540, 421, 21))
        self.line_5.setFrameShape(QtGui.QFrame.HLine)
        self.line_5.setFrameShadow(QtGui.QFrame.Sunken)
        self.line_5.setObjectName(_fromUtf8("line_5"))
        self.report_parameter_value = QtGui.QLineEdit(self.rad_transf_model_tab)
        self.report_parameter_value.setGeometry(QtCore.QRect(160, 570, 121, 21))
        self.report_parameter_value.setObjectName(_fromUtf8("report_parameter_value"))
        self.report_parameter_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.report_parameter_label.setGeometry(QtCore.QRect(20, 570, 131, 21))
        self.report_parameter_label.setObjectName(_fromUtf8("report_parameter_label"))
        self.batch_name_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.batch_name_label.setGeometry(QtCore.QRect(20, 40, 91, 21))
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.batch_name_label.sizePolicy().hasHeightForWidth())
        self.batch_name_label.setSizePolicy(sizePolicy)
        self.batch_name_label.setObjectName(_fromUtf8("batch_name_label"))
        self.batch_name_value = QtGui.QLineEdit(self.rad_transf_model_tab)
        self.batch_name_value.setGeometry(QtCore.QRect(120, 40, 141, 21))
        self.batch_name_value.setObjectName(_fromUtf8("batch_name_value"))
        self.open_result_file_button = QtGui.QPushButton(self.rad_transf_model_tab)
        self.open_result_file_button.setGeometry(QtCore.QRect(600, 500, 121, 31))
        self.open_result_file_button.setObjectName(_fromUtf8("open_result_file_button"))
        self.saa_values = QtGui.QLineEdit(self.rad_transf_model_tab)
        self.saa_values.setGeometry(QtCore.QRect(120, 70, 401, 21))
        self.saa_values.setObjectName(_fromUtf8("saa_values"))
        self.sza_values = QtGui.QLineEdit(self.rad_transf_model_tab)
        self.sza_values.setGeometry(QtCore.QRect(120, 100, 401, 21))
        self.sza_values.setObjectName(_fromUtf8("sza_values"))
        self.saa_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.saa_label.setGeometry(QtCore.QRect(20, 70, 81, 21))
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.saa_label.sizePolicy().hasHeightForWidth())
        self.saa_label.setSizePolicy(sizePolicy)
        self.saa_label.setObjectName(_fromUtf8("saa_label"))
        self.sza_label = QtGui.QLabel(self.rad_transf_model_tab)
        self.sza_label.setGeometry(QtCore.QRect(20, 100, 81, 21))
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sza_label.sizePolicy().hasHeightForWidth())
        self.sza_label.setSizePolicy(sizePolicy)
        self.sza_label.setObjectName(_fromUtf8("sza_label"))
        self.show_grid = QtGui.QCheckBox(self.rad_transf_model_tab)
        self.show_grid.setGeometry(QtCore.QRect(600, 470, 61, 22))
        self.show_grid.setObjectName(_fromUtf8("show_grid"))
        self.mouse_coordinate = QtGui.QLabel(self.rad_transf_model_tab)
        self.mouse_coordinate.setGeometry(QtCore.QRect(728, 551, 121, 21))
        self.mouse_coordinate.setObjectName(_fromUtf8("mouse_coordinate"))
        self.label_3 = QtGui.QLabel(self.rad_transf_model_tab)
        self.label_3.setGeometry(QtCore.QRect(585, 551, 141, 21))
        self.label_3.setObjectName(_fromUtf8("label_3"))
        self.label_4 = QtGui.QLabel(self.rad_transf_model_tab)
        self.label_4.setGeometry(QtCore.QRect(610, 630, 151, 51))
        self.label_4.setText(_fromUtf8(""))
        self.label_4.setPixmap(QtGui.QPixmap(_fromUtf8(":/icons/Icons/bbp.png")))
        self.label_4.setObjectName(_fromUtf8("label_4"))
        self.label_5 = QtGui.QLabel(self.rad_transf_model_tab)
        self.label_5.setGeometry(QtCore.QRect(610, 700, 211, 21))
        self.label_5.setText(_fromUtf8(""))
        self.label_5.setPixmap(QtGui.QPixmap(_fromUtf8(":/icons/Icons/CDOM.png")))
        self.label_5.setObjectName(_fromUtf8("label_5"))
        self.label_6 = QtGui.QLabel(self.rad_transf_model_tab)
        self.label_6.setGeometry(QtCore.QRect(586, 600, 161, 17))
        self.label_6.setObjectName(_fromUtf8("label_6"))
        self.line_6 = QtGui.QFrame(self.rad_transf_model_tab)
        self.line_6.setGeometry(QtCore.QRect(605, 576, 201, 20))
        self.line_6.setFrameShape(QtGui.QFrame.HLine)
        self.line_6.setFrameShadow(QtGui.QFrame.Sunken)
        self.line_6.setObjectName(_fromUtf8("line_6"))
        self.label_11 = QtGui.QLabel(self.rad_transf_model_tab)
        self.label_11.setGeometry(QtCore.QRect(524, 70, 41, 21))
        self.label_11.setObjectName(_fromUtf8("label_11"))
        self.label_13 = QtGui.QLabel(self.rad_transf_model_tab)
        self.label_13.setGeometry(QtCore.QRect(524, 100, 41, 21))
        self.label_13.setObjectName(_fromUtf8("label_13"))
        self.label_7 = QtGui.QLabel(self.rad_transf_model_tab)
        self.label_7.setGeometry(QtCore.QRect(154, 159, 31, 17))
        self.label_7.setText(_fromUtf8(""))
        self.label_7.setPixmap(QtGui.QPixmap(_fromUtf8(":/icons/Icons/b_bp_small.png")))
        self.label_7.setObjectName(_fromUtf8("label_7"))
        self.label_8 = QtGui.QLabel(self.rad_transf_model_tab)
        self.label_8.setGeometry(QtCore.QRect(160, 241, 31, 17))
        self.label_8.setText(_fromUtf8(""))
        self.label_8.setPixmap(QtGui.QPixmap(_fromUtf8(":/icons/Icons/ag.png")))
        self.label_8.setObjectName(_fromUtf8("label_8"))
        self.sza_values_3 = QtGui.QLineEdit(self.rad_transf_model_tab)
        self.sza_values_3.setGeometry(QtCore.QRect(420, 600, 51, 21))
        self.sza_values_3.setObjectName(_fromUtf8("sza_values_3"))
        self.saa_label_3 = QtGui.QLabel(self.rad_transf_model_tab)
        self.saa_label_3.setGeometry(QtCore.QRect(310, 570, 101, 21))
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.saa_label_3.sizePolicy().hasHeightForWidth())
        self.saa_label_3.setSizePolicy(sizePolicy)
        self.saa_label_3.setObjectName(_fromUtf8("saa_label_3"))
        self.saa_values_3 = QtGui.QLineEdit(self.rad_transf_model_tab)
        self.saa_values_3.setGeometry(QtCore.QRect(420, 570, 51, 21))
        self.saa_values_3.setObjectName(_fromUtf8("saa_values_3"))
        self.label_61 = QtGui.QLabel(self.rad_transf_model_tab)
        self.label_61.setGeometry(QtCore.QRect(490, 600, 41, 21))
        self.label_61.setObjectName(_fromUtf8("label_61"))
        self.label_62 = QtGui.QLabel(self.rad_transf_model_tab)
        self.label_62.setGeometry(QtCore.QRect(490, 570, 41, 21))
        self.label_62.setObjectName(_fromUtf8("label_62"))
        self.sza_label_3 = QtGui.QLabel(self.rad_transf_model_tab)
        self.sza_label_3.setGeometry(QtCore.QRect(310, 600, 91, 21))
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.sza_label_3.sizePolicy().hasHeightForWidth())
        self.sza_label_3.setSizePolicy(sizePolicy)
        self.sza_label_3.setObjectName(_fromUtf8("sza_label_3"))
        self.tabWidget.addTab(self.rad_transf_model_tab, _fromUtf8(""))
        self.reverse_tab = QtGui.QWidget()
        self.reverse_tab.setObjectName(_fromUtf8("reverse_tab"))
        self.line_2 = QtGui.QFrame(self.reverse_tab)
        self.line_2.setGeometry(QtCore.QRect(560, 0, 20, 721))
        self.line_2.setFrameShape(QtGui.QFrame.VLine)
        self.line_2.setFrameShadow(QtGui.QFrame.Sunken)
        self.line_2.setObjectName(_fromUtf8("line_2"))
        self.label_20 = QtGui.QLabel(self.reverse_tab)
        self.label_20.setGeometry(QtCore.QRect(580, 400, 66, 17))
        self.label_20.setObjectName(_fromUtf8("label_20"))
        self.radioButton_2 = QtGui.QRadioButton(self.reverse_tab)
        self.radioButton_2.setGeometry(QtCore.QRect(80, 110, 116, 22))
        self.radioButton_2.setObjectName(_fromUtf8("radioButton_2"))
        self.radioButton_3 = QtGui.QRadioButton(self.reverse_tab)
        self.radioButton_3.setGeometry(QtCore.QRect(80, 140, 116, 22))
        self.radioButton_3.setObjectName(_fromUtf8("radioButton_3"))
        self.label_19 = QtGui.QLabel(self.reverse_tab)
        self.label_19.setGeometry(QtCore.QRect(40, 50, 101, 16))
        self.label_19.setObjectName(_fromUtf8("label_19"))
        self.label_18 = QtGui.QLabel(self.reverse_tab)
        self.label_18.setGeometry(QtCore.QRect(10, 20, 191, 16))
        self.label_18.setObjectName(_fromUtf8("label_18"))
        self.x_value_reverse = QtGui.QLineEdit(self.reverse_tab)
        self.x_value_reverse.setGeometry(QtCore.QRect(710, 480, 51, 21))
        self.x_value_reverse.setObjectName(_fromUtf8("x_value_reverse"))
        self.label_27 = QtGui.QLabel(self.reverse_tab)
        self.label_27.setGeometry(QtCore.QRect(650, 600, 21, 16))
        self.label_27.setObjectName(_fromUtf8("label_27"))
        self.label_22 = QtGui.QLabel(self.reverse_tab)
        self.label_22.setGeometry(QtCore.QRect(610, 460, 151, 21))
        self.label_22.setObjectName(_fromUtf8("label_22"))
        self.label_29 = QtGui.QLabel(self.reverse_tab)
        self.label_29.setGeometry(QtCore.QRect(770, 630, 21, 16))
        self.label_29.setObjectName(_fromUtf8("label_29"))
        self.label_24 = QtGui.QLabel(self.reverse_tab)
        self.label_24.setGeometry(QtCore.QRect(650, 510, 21, 16))
        self.label_24.setObjectName(_fromUtf8("label_24"))
        self.label_23 = QtGui.QLabel(self.reverse_tab)
        self.label_23.setGeometry(QtCore.QRect(650, 480, 21, 16))
        self.label_23.setObjectName(_fromUtf8("label_23"))
        self.y_value_reverse = QtGui.QLineEdit(self.reverse_tab)
        self.y_value_reverse.setGeometry(QtCore.QRect(710, 510, 51, 21))
        self.y_value_reverse.setObjectName(_fromUtf8("y_value_reverse"))
        self.label_21 = QtGui.QLabel(self.reverse_tab)
        self.label_21.setGeometry(QtCore.QRect(610, 430, 71, 16))
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_21.sizePolicy().hasHeightForWidth())
        self.label_21.setSizePolicy(sizePolicy)
        self.label_21.setObjectName(_fromUtf8("label_21"))
        self.label_30 = QtGui.QLabel(self.reverse_tab)
        self.label_30.setGeometry(QtCore.QRect(610, 660, 101, 16))
        self.label_30.setObjectName(_fromUtf8("label_30"))
        self.label_25 = QtGui.QLabel(self.reverse_tab)
        self.label_25.setGeometry(QtCore.QRect(610, 540, 151, 21))
        self.label_25.setObjectName(_fromUtf8("label_25"))
        self.g_value_reverse = QtGui.QLineEdit(self.reverse_tab)
        self.g_value_reverse.setGeometry(QtCore.QRect(710, 560, 51, 21))
        self.g_value_reverse.setObjectName(_fromUtf8("g_value_reverse"))
        self.p_values_reverse = QtGui.QLineEdit(self.reverse_tab)
        self.p_values_reverse.setGeometry(QtCore.QRect(710, 430, 311, 21))
        self.p_values_reverse.setObjectName(_fromUtf8("p_values_reverse"))
        self.s_value_reverse = QtGui.QLineEdit(self.reverse_tab)
        self.s_value_reverse.setGeometry(QtCore.QRect(710, 600, 51, 21))
        self.s_value_reverse.setObjectName(_fromUtf8("s_value_reverse"))
        self.label_28 = QtGui.QLabel(self.reverse_tab)
        self.label_28.setGeometry(QtCore.QRect(610, 630, 71, 16))
        self.label_28.setObjectName(_fromUtf8("label_28"))
        self.wavelength_values_reverse = QtGui.QLineEdit(self.reverse_tab)
        self.wavelength_values_reverse.setGeometry(QtCore.QRect(710, 660, 311, 21))
        self.wavelength_values_reverse.setObjectName(_fromUtf8("wavelength_values_reverse"))
        self.z_value_reverse = QtGui.QLineEdit(self.reverse_tab)
        self.z_value_reverse.setGeometry(QtCore.QRect(710, 630, 51, 21))
        self.z_value_reverse.setObjectName(_fromUtf8("z_value_reverse"))
        self.label_26 = QtGui.QLabel(self.reverse_tab)
        self.label_26.setGeometry(QtCore.QRect(650, 560, 21, 16))
        self.label_26.setObjectName(_fromUtf8("label_26"))
        self.graphicsView_4 = QtGui.QGraphicsView(self.reverse_tab)
        self.graphicsView_4.setGeometry(QtCore.QRect(580, 10, 791, 351))
        self.graphicsView_4.setObjectName(_fromUtf8("graphicsView_4"))
        self.widget_2 = QtGui.QWidget(self.reverse_tab)
        self.widget_2.setGeometry(QtCore.QRect(570, 0, 811, 371))
        self.widget_2.setObjectName(_fromUtf8("widget_2"))
        self.label_33 = QtGui.QLabel(self.reverse_tab)
        self.label_33.setGeometry(QtCore.QRect(580, 370, 41, 16))
        self.label_33.setObjectName(_fromUtf8("label_33"))
        self.label_15 = QtGui.QLabel(self.reverse_tab)
        self.label_15.setGeometry(QtCore.QRect(1040, 660, 31, 16))
        self.label_15.setObjectName(_fromUtf8("label_15"))
        self.sens_2 = QtGui.QSlider(self.reverse_tab)
        self.sens_2.setEnabled(True)
        self.sens_2.setGeometry(QtCore.QRect(630, 360, 741, 31))
        self.sens_2.setCursor(QtGui.QCursor(QtCore.Qt.ArrowCursor))
        self.sens_2.setAutoFillBackground(False)
        self.sens_2.setOrientation(QtCore.Qt.Horizontal)
        self.sens_2.setObjectName(_fromUtf8("sens_2"))
        self.tabWidget.addTab(self.reverse_tab, _fromUtf8(""))
        self.progressBar = QtGui.QProgressBar(self.centralwidget)
        self.progressBar.setGeometry(QtCore.QRect(130, 796, 331, 21))
        self.progressBar.setMouseTracking(False)
        self.progressBar.setProperty("value", 24)
        self.progressBar.setTextVisible(True)
        self.progressBar.setTextDirection(QtGui.QProgressBar.TopToBottom)
        self.progressBar.setObjectName(_fromUtf8("progressBar"))
        self.cancel = QtGui.QPushButton(self.centralwidget)
        self.cancel.setGeometry(QtCore.QRect(470, 790, 101, 31))
        self.cancel.setObjectName(_fromUtf8("cancel"))
        self.quit = QtGui.QPushButton(self.centralwidget)
        self.quit.setGeometry(QtCore.QRect(1270, 790, 101, 31))
        self.quit.setObjectName(_fromUtf8("quit"))
        self.error_text_label = QtGui.QLabel(self.centralwidget)
        self.error_text_label.setGeometry(QtCore.QRect(850, 790, 241, 31))
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.error_text_label.sizePolicy().hasHeightForWidth())
        self.error_text_label.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(15)
        font.setBold(True)
        font.setItalic(False)
        font.setUnderline(True)
        font.setWeight(75)
        font.setStrikeOut(False)
        font.setKerning(True)
        self.error_text_label.setFont(font)
        self.error_text_label.setCursor(QtGui.QCursor(QtCore.Qt.ArrowCursor))
        self.error_text_label.setContextMenuPolicy(QtCore.Qt.DefaultContextMenu)
        self.error_text_label.setAcceptDrops(False)
        self.error_text_label.setAccessibleName(_fromUtf8(""))
        self.error_text_label.setAccessibleDescription(_fromUtf8(""))
        self.error_text_label.setAutoFillBackground(False)
        self.error_text_label.setInputMethodHints(QtCore.Qt.ImhNone)
        self.error_text_label.setScaledContents(False)
        self.error_text_label.setWordWrap(False)
        self.error_text_label.setOpenExternalLinks(False)
        self.error_text_label.setTextInteractionFlags(QtCore.Qt.LinksAccessibleByMouse)
        self.error_text_label.setObjectName(_fromUtf8("error_text_label"))
        self.error_label = QtGui.QLabel(self.centralwidget)
        self.error_label.setGeometry(QtCore.QRect(800, 780, 51, 51))
        self.error_label.setText(_fromUtf8(""))
        self.error_label.setPixmap(QtGui.QPixmap(_fromUtf8("../../../.designer/backup/Icons/beCareful.png")))
        self.error_label.setScaledContents(True)
        self.error_label.setObjectName(_fromUtf8("error_label"))
        MainWindow.setCentralWidget(self.centralwidget)
        self.statusbar = QtGui.QStatusBar(MainWindow)
        self.statusbar.setObjectName(_fromUtf8("statusbar"))
        MainWindow.setStatusBar(self.statusbar)
        self.menuBar = QtGui.QMenuBar(MainWindow)
        self.menuBar.setEnabled(True)
        self.menuBar.setGeometry(QtCore.QRect(0, 0, 1362, 25))
        self.menuBar.setDefaultUp(False)
        self.menuBar.setNativeMenuBar(True)
        self.menuBar.setObjectName(_fromUtf8("menuBar"))
        self.menuEssai = QtGui.QMenu(self.menuBar)
        self.menuEssai.setObjectName(_fromUtf8("menuEssai"))
        self.menuFigure = QtGui.QMenu(self.menuBar)
        self.menuFigure.setObjectName(_fromUtf8("menuFigure"))
        self.menuAbout = QtGui.QMenu(self.menuBar)
        self.menuAbout.setObjectName(_fromUtf8("menuAbout"))
        self.menuHelp = QtGui.QMenu(self.menuBar)
        self.menuHelp.setObjectName(_fromUtf8("menuHelp"))
        MainWindow.setMenuBar(self.menuBar)
        self.toolBar = QtGui.QToolBar(MainWindow)
        palette = QtGui.QPalette()
        brush = QtGui.QBrush(QtGui.QColor(76, 76, 76))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.WindowText, brush)
        brush = QtGui.QBrush(QtGui.QColor(60, 60, 60))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Button, brush)
        brush = QtGui.QBrush(QtGui.QColor(63, 61, 61))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Midlight, brush)
        brush = QtGui.QBrush(QtGui.QColor(36, 36, 35))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Dark, brush)
        brush = QtGui.QBrush(QtGui.QColor(34, 32, 32))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Mid, brush)
        brush = QtGui.QBrush(QtGui.QColor(60, 60, 60))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Text, brush)
        brush = QtGui.QBrush(QtGui.QColor(76, 76, 76))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.ButtonText, brush)
        brush = QtGui.QBrush(QtGui.QColor(26, 26, 26))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Base, brush)
        brush = QtGui.QBrush(QtGui.QColor(10, 22, 25))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Window, brush)
        brush = QtGui.QBrush(QtGui.QColor(27, 27, 27))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Shadow, brush)
        brush = QtGui.QBrush(QtGui.QColor(76, 76, 76))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.WindowText, brush)
        brush = QtGui.QBrush(QtGui.QColor(60, 60, 60))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Button, brush)
        brush = QtGui.QBrush(QtGui.QColor(63, 61, 61))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Midlight, brush)
        brush = QtGui.QBrush(QtGui.QColor(36, 36, 35))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Dark, brush)
        brush = QtGui.QBrush(QtGui.QColor(34, 32, 32))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Mid, brush)
        brush = QtGui.QBrush(QtGui.QColor(60, 60, 60))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Text, brush)
        brush = QtGui.QBrush(QtGui.QColor(76, 76, 76))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.ButtonText, brush)
        brush = QtGui.QBrush(QtGui.QColor(26, 26, 26))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Base, brush)
        brush = QtGui.QBrush(QtGui.QColor(10, 22, 25))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Window, brush)
        brush = QtGui.QBrush(QtGui.QColor(27, 27, 27))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Shadow, brush)
        brush = QtGui.QBrush(QtGui.QColor(36, 36, 35))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.WindowText, brush)
        brush = QtGui.QBrush(QtGui.QColor(60, 60, 60))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Button, brush)
        brush = QtGui.QBrush(QtGui.QColor(63, 61, 61))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Midlight, brush)
        brush = QtGui.QBrush(QtGui.QColor(36, 36, 35))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Dark, brush)
        brush = QtGui.QBrush(QtGui.QColor(34, 32, 32))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Mid, brush)
        brush = QtGui.QBrush(QtGui.QColor(36, 36, 35))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Text, brush)
        brush = QtGui.QBrush(QtGui.QColor(36, 36, 35))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.ButtonText, brush)
        brush = QtGui.QBrush(QtGui.QColor(10, 22, 25))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Base, brush)
        brush = QtGui.QBrush(QtGui.QColor(10, 22, 25))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Window, brush)
        brush = QtGui.QBrush(QtGui.QColor(27, 27, 27))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Shadow, brush)
        self.toolBar.setPalette(palette)
        self.toolBar.setAutoFillBackground(True)
        self.toolBar.setMovable(False)
        self.toolBar.setToolButtonStyle(QtCore.Qt.ToolButtonIconOnly)
        self.toolBar.setFloatable(False)
        self.toolBar.setObjectName(_fromUtf8("toolBar"))
        MainWindow.addToolBar(QtCore.Qt.TopToolBarArea, self.toolBar)
        self.actionDd = QtGui.QAction(MainWindow)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/Icons/i_document-open.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionDd.setIcon(icon)
        self.actionDd.setObjectName(_fromUtf8("actionDd"))
        self.actionQuit = QtGui.QAction(MainWindow)
        self.actionQuit.setObjectName(_fromUtf8("actionQuit"))
        self.actionSave = QtGui.QAction(MainWindow)
        self.actionSave.setObjectName(_fromUtf8("actionSave"))
        self.actionSave_as = QtGui.QAction(MainWindow)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/Icons/i_document-save.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionSave_as.setIcon(icon1)
        self.actionSave_as.setObjectName(_fromUtf8("actionSave_as"))
        self.actionOpen = QtGui.QAction(MainWindow)
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(_fromUtf8("../../../.designer/backup/Icons/document-open.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionOpen.setIcon(icon2)
        self.actionOpen.setIconVisibleInMenu(True)
        self.actionOpen.setObjectName(_fromUtf8("actionOpen"))
        self.actionRun = QtGui.QAction(MainWindow)
        self.actionRun.setObjectName(_fromUtf8("actionRun"))
        self.actionLog_file = QtGui.QAction(MainWindow)
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/Icons/i_view-refresh.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionLog_file.setIcon(icon3)
        self.actionLog_file.setObjectName(_fromUtf8("actionLog_file"))
        self.actionDocumentation = QtGui.QAction(MainWindow)
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/Icons/i_help-contents.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionDocumentation.setIcon(icon4)
        self.actionDocumentation.setObjectName(_fromUtf8("actionDocumentation"))
        self.actionThis_GUI = QtGui.QAction(MainWindow)
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap(_fromUtf8(":/icons/Icons/i_help-about.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionThis_GUI.setIcon(icon5)
        self.actionThis_GUI.setObjectName(_fromUtf8("actionThis_GUI"))
        self.menuEssai.addAction(self.actionOpen)
        self.menuEssai.addSeparator()
        self.menuEssai.addAction(self.actionRun)
        self.menuEssai.addSeparator()
        self.menuEssai.addAction(self.actionQuit)
        self.menuFigure.addAction(self.actionSave)
        self.menuFigure.addAction(self.actionSave_as)
        self.menuAbout.addAction(self.actionThis_GUI)
        self.menuHelp.addAction(self.actionLog_file)
        self.menuHelp.addAction(self.actionDocumentation)
        self.menuBar.addAction(self.menuEssai.menuAction())
        self.menuBar.addAction(self.menuFigure.menuAction())
        self.menuBar.addAction(self.menuAbout.menuAction())
        self.menuBar.addAction(self.menuHelp.menuAction())
        self.toolBar.addAction(self.actionDd)
        self.toolBar.addAction(self.actionSave_as)
        self.toolBar.addAction(self.actionDocumentation)
        self.toolBar.addAction(self.actionLog_file)
        self.toolBar.addAction(self.actionThis_GUI)
        self.p_label.setBuddy(self.p_values)
        self.execPath_label.setBuddy(self.exec_path_button)
        self.cpu_label.setBuddy(self.nb_cpu)
        self.x_label.setBuddy(self.x_value)
        self.y_label.setBuddy(self.y_value)
        self.g_label.setBuddy(self.g_value)
        self.s_label.setBuddy(self.s_value)
        self.z_label.setBuddy(self.z_value)
        self.waveL_label.setBuddy(self.wavelength_values)
        self.phyto_label.setBuddy(self.phyto_button)
        self.bottom_label.setBuddy(self.bottom_button)
        self.verbose_label.setBuddy(self.verbose_value)
        self.report_parameter_label.setBuddy(self.report_parameter_value)
        self.batch_name_label.setBuddy(self.batch_name_value)
        self.saa_label.setBuddy(self.saa_values)
        self.sza_label.setBuddy(self.sza_values)
        self.saa_label_3.setBuddy(self.saa_values)
        self.sza_label_3.setBuddy(self.sza_values)
        self.label_27.setBuddy(self.s_value_reverse)
        self.label_24.setBuddy(self.y_value_reverse)
        self.label_23.setBuddy(self.x_value_reverse)
        self.label_21.setBuddy(self.p_values_reverse)
        self.label_30.setBuddy(self.wavelength_values_reverse)
        self.label_28.setBuddy(self.z_value_reverse)
        self.label_26.setBuddy(self.g_value_reverse)
        self.label_33.setBuddy(self.sens_2)

        self.retranslateUi(MainWindow)
        self.tabWidget.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)
        MainWindow.setTabOrder(self.tabWidget, self.batch_name_value)
        MainWindow.setTabOrder(self.batch_name_value, self.saa_values)
        MainWindow.setTabOrder(self.saa_values, self.sza_values)
        MainWindow.setTabOrder(self.sza_values, self.p_values)
        MainWindow.setTabOrder(self.p_values, self.x_value)
        MainWindow.setTabOrder(self.x_value, self.y_value)
        MainWindow.setTabOrder(self.y_value, self.g_value)
        MainWindow.setTabOrder(self.g_value, self.s_value)
        MainWindow.setTabOrder(self.s_value, self.z_value)
        MainWindow.setTabOrder(self.z_value, self.wavelength_values)
        MainWindow.setTabOrder(self.wavelength_values, self.report_parameter_value)
        MainWindow.setTabOrder(self.report_parameter_value, self.verbose_value)
        MainWindow.setTabOrder(self.verbose_value, self.nb_cpu)
        MainWindow.setTabOrder(self.nb_cpu, self.show_all_curves)
        MainWindow.setTabOrder(self.show_all_curves, self.show_grid)
        MainWindow.setTabOrder(self.show_grid, self.bottom_button)
        MainWindow.setTabOrder(self.bottom_button, self.phyto_button)
        MainWindow.setTabOrder(self.phyto_button, self.exec_path_button)
        MainWindow.setTabOrder(self.exec_path_button, self.run)
        MainWindow.setTabOrder(self.run, self.cancel)
        MainWindow.setTabOrder(self.cancel, self.open_result_file_button)
        MainWindow.setTabOrder(self.open_result_file_button, self.quit)
        MainWindow.setTabOrder(self.quit, self.bottom_path)
        MainWindow.setTabOrder(self.bottom_path, self.phyto_path)
        MainWindow.setTabOrder(self.phyto_path, self.exec_path)
        MainWindow.setTabOrder(self.exec_path, self.graphicsView_3)
        MainWindow.setTabOrder(self.graphicsView_3, self.radioButton_3)
        MainWindow.setTabOrder(self.radioButton_3, self.x_value_reverse)
        MainWindow.setTabOrder(self.x_value_reverse, self.y_value_reverse)
        MainWindow.setTabOrder(self.y_value_reverse, self.g_value_reverse)
        MainWindow.setTabOrder(self.g_value_reverse, self.p_values_reverse)
        MainWindow.setTabOrder(self.p_values_reverse, self.s_value_reverse)
        MainWindow.setTabOrder(self.s_value_reverse, self.wavelength_values_reverse)
        MainWindow.setTabOrder(self.wavelength_values_reverse, self.z_value_reverse)
        MainWindow.setTabOrder(self.z_value_reverse, self.graphicsView_4)
        MainWindow.setTabOrder(self.graphicsView_4, self.sens_2)
        MainWindow.setTabOrder(self.sens_2, self.radioButton_2)

    def retranslateUi(self, MainWindow):
        MainWindow.setWindowTitle(_translate("MainWindow", "PlanarRad", None))
        self.run.setText(_translate("MainWindow", "Run", None))
        self.p_label.setText(_translate("MainWindow", "P values ", None))
        self.execPath_label.setText(_translate("MainWindow", "Path to Planarrad", None))
        self.cpu_label.setText(_translate("MainWindow", "Number of CPU ", None))
        self.label_17.setText(_translate("MainWindow", "Sens.", None))
        self.exec_path.setText(_translate("MainWindow", "/home/marrabld/Apps/jude2_install/bin", None))
        self.p_values.setText(_translate("MainWindow", "0.1", None))
        self.title_label.setText(_translate("MainWindow", "Set the optical parameters list (comma seperated)", None))
        self.particles_label.setText(_translate("MainWindow", "Particle scattering", None))
        self.x_value.setText(_translate("MainWindow", "0.01", None))
        self.y_value.setText(_translate("MainWindow", "1.0", None))
        self.x_label.setText(_translate("MainWindow", "X :", None))
        self.y_label.setText(_translate("MainWindow", "Y :", None))
        self.organic_label.setText(_translate("MainWindow", "Organic absorption", None))
        self.s_value.setText(_translate("MainWindow", "0.015", None))
        self.g_value.setText(_translate("MainWindow", "0.01", None))
        self.g_label.setText(_translate("MainWindow", "G :", None))
        self.s_label.setText(_translate("MainWindow", "S :", None))
        self.z_label.setText(_translate("MainWindow", "Depth (Z) ", None))
        self.z_value.setText(_translate("MainWindow", "10.0", None))
        self.label_10.setText(_translate("MainWindow", "(m)", None))
        self.exec_path_button.setText(_translate("MainWindow", "DIrectory", None))
        self.waveL_label.setText(_translate("MainWindow", "Wavelengths ", None))
        self.wavelength_values.setText(_translate("MainWindow", "410.0, 430.0, 450.0, 470.0, 490.0, 510.0, 530.0, 550.0, 570.0, 590.0, 610.0, 630.0, 650.0, 670.0, 690.0, 710.0, 730.0", None))
        self.phyto_label.setText(_translate("MainWindow", "Phytoplankton absorption ", None))
        self.phyto_button.setText(_translate("MainWindow", "File", None))
        self.phyto_path.setText(_translate("MainWindow", "/home/marrabld/Projects/planarradpy/inputs/iop_files/a_phi.csv", None))
        self.bottom_label.setText(_translate("MainWindow", "Bottom reflectance ", None))
        self.bottom_path.setText(_translate("MainWindow", "/home/marrabld/Projects/planarradpy/inputs/bottom_files/ger_sand17.txt", None))
        self.bottom_button.setText(_translate("MainWindow", "File", None))
        self.verbose_label.setText(_translate("MainWindow", "Verbose ", None))
        self.label_14.setText(_translate("MainWindow", "(nm)", None))
        self.label_31.setText(_translate("MainWindow", "(1 -> 6)", None))
        self.label_32.setText(_translate("MainWindow", "(-1 means all CPUs)", None))
        self.label.setText(_translate("MainWindow", "Plot tools (options)", None))
        self.label_2.setText(_translate("MainWindow", "<html><head/><body><p>Modelled Parameters</p></body></html>", None))
        self.show_all_curves.setText(_translate("MainWindow", "All curves", None))
        self.report_parameter_value.setText(_translate("MainWindow", "Rrs", None))
        self.report_parameter_label.setText(_translate("MainWindow", "Report parameter ", None))
        self.batch_name_label.setText(_translate("MainWindow", "Batch name ", None))
        self.batch_name_value.setText(_translate("MainWindow", "default", None))
        self.open_result_file_button.setText(_translate("MainWindow", "Open report", None))
        self.saa_values.setText(_translate("MainWindow", "0.0", None))
        self.sza_values.setText(_translate("MainWindow", "0.0", None))
        self.saa_label.setText(_translate("MainWindow", "SAA values ", None))
        self.sza_label.setText(_translate("MainWindow", "SZA values ", None))
        self.show_grid.setText(_translate("MainWindow", "Grid", None))
        self.mouse_coordinate.setText(_translate("MainWindow", "(x, y)", None))
        self.label_3.setText(_translate("MainWindow", "Mouse coordinates :", None))
        self.label_6.setText(_translate("MainWindow", "Bio-optical Models:", None))
        self.label_11.setText(_translate("MainWindow", "(deg)", None))
        self.label_13.setText(_translate("MainWindow", "(deg)", None))
        self.sza_values_3.setText(_translate("MainWindow", "0.0", None))
        self.saa_label_3.setText(_translate("MainWindow", "View Azimuth", None))
        self.saa_values_3.setText(_translate("MainWindow", "0.0", None))
        self.label_61.setText(_translate("MainWindow", "(deg)", None))
        self.label_62.setText(_translate("MainWindow", "(deg)", None))
        self.sza_label_3.setText(_translate("MainWindow", "View Zenith", None))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.rad_transf_model_tab), _translate("MainWindow", "Radiative Transfer Model", None))
        self.label_20.setText(_translate("MainWindow", "Details :", None))
        self.radioButton_2.setText(_translate("MainWindow", "HOPE (1999)", None))
        self.radioButton_3.setText(_translate("MainWindow", "RadioButton", None))
        self.label_19.setText(_translate("MainWindow", "Tool (method) :", None))
        self.label_18.setText(_translate("MainWindow", "Deconvolution parameters :", None))
        self.label_27.setText(_translate("MainWindow", "s :", None))
        self.label_22.setText(_translate("MainWindow", "Particules scaterring :", None))
        self.label_29.setText(_translate("MainWindow", "(m)", None))
        self.label_24.setText(_translate("MainWindow", "y :", None))
        self.label_23.setText(_translate("MainWindow", "x :", None))
        self.label_21.setText(_translate("MainWindow", "P values :", None))
        self.label_30.setText(_translate("MainWindow", "Wavelengths :", None))
        self.label_25.setText(_translate("MainWindow", "Organic absorption :", None))
        self.label_28.setText(_translate("MainWindow", "Depth (z) :", None))
        self.label_26.setText(_translate("MainWindow", "g :", None))
        self.label_33.setText(_translate("MainWindow", "Sens.", None))
        self.label_15.setText(_translate("MainWindow", "(nm)", None))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.reverse_tab), _translate("MainWindow", "Inverse", None))
        self.cancel.setText(_translate("MainWindow", "Cancel", None))
        self.quit.setText(_translate("MainWindow", "Quit", None))
        self.error_text_label.setText(_translate("MainWindow", "Check values !", None))
        self.menuEssai.setTitle(_translate("MainWindow", "File", None))
        self.menuFigure.setTitle(_translate("MainWindow", "Figure", None))
        self.menuAbout.setTitle(_translate("MainWindow", "About", None))
        self.menuHelp.setTitle(_translate("MainWindow", "Help !", None))
        self.toolBar.setWindowTitle(_translate("MainWindow", "toolBar", None))
        self.actionDd.setText(_translate("MainWindow", "Open", None))
        self.actionQuit.setText(_translate("MainWindow", "Quit", None))
        self.actionSave.setText(_translate("MainWindow", "Save", None))
        self.actionSave_as.setText(_translate("MainWindow", "Save As ...", None))
        self.actionOpen.setText(_translate("MainWindow", "Open", None))
        self.actionRun.setText(_translate("MainWindow", "Run", None))
        self.actionLog_file.setText(_translate("MainWindow", "Log file", None))
        self.actionDocumentation.setText(_translate("MainWindow", "Documentation", None))
        self.actionThis_GUI.setText(_translate("MainWindow", "This GUI !", None))

from gui_matplotlibwidgetFile import matplotlibWidget
import resources_rc



__author__ = 'marrabld'

import logging.config
import os

log_conf_file = os.path.join(os.path.dirname(__file__), 'logging.conf')
print(log_conf_file)
#log_conf_file = ('logging.conf')
logging.config.fileConfig(log_conf_file)

# create logger
logger = logging.getLogger('libplanarradpy')


def clear_log():
    """
    This method will clear the log file by reopening the file for writing.
    """
    with open('libplanarradpy.log', 'w'):
        pass


def clear_err():
    """
    This method will clear the log file by reopening the file for writing.
    """

    with open('libplanarradpy.err', 'w'):
        pass


#!/usr/bin/env python

__author__ = 'boulefi'

import sys
import scipy
import os

sys.path.append("../gui")
sys.path.append("../")

import unittest
import gui.gui_batch


class TestBatchFile(unittest.TestCase):
    def setUp(self):
        """
        The following defines defaults values to check if the script transmit them well.
        """
        # Here you set up what you need for your tests.

        batch_name = 'unit_test_test_gui_batch'
        p_values = 0.01, 0.1
        x_value = 0.1
        y_value = 1.0
        g_value = 0.1
        s_value = 0.014
        z_value = 20
        wavelength_values = [410.0, 430.0, 450.0, 470.0, 490.0, 510.0, 530.0, 550.0, 570.0, 590.0, 610.0, 630.0, 650.0, 670.0, 690.0, 710.0, 730.0]
        verbose_value = 6
        phyto_path = '/home/boulefi/PycharmProjects/planarradpy/inputs/iop_files/a_phi.csv'
        bottom_path = '/home/boulefi/PycharmProjects/planarradpy/inputs/bottom_files/all_zeros17.txt'
        nb_cpu = -1
        exec_path = '/home/boulefi/jude2_install/bin'
        saa_values = 40
        sza_values = 90.0, 130.0
        report_parameter_value = 'Rrs'
        self.key_array = []
        self.val_array = []

        self.gui_batch = gui.gui_batch.BatchFile(batch_name, p_values, x_value, y_value, g_value, s_value, z_value,
                                                 wavelength_values, verbose_value, phyto_path, bottom_path, nb_cpu,
                                                 exec_path, saa_values, sza_values, report_parameter_value)

    def test_write_batch_to_file_open(self):
        """
        This test will check if the function 'write_batch_to_file' in '/gui/gui_batch' works
        and create the batch file as we want.
        """

        path = '../inputs/batch_files/batch_test_default.txt'

        self.gui_batch.write_batch_to_file()

        #-------------------------------------------------------------------------------#
        #The following will check that the file exists in the place you expect it to be
        #and I will check the file's size is correct
        #-------------------------------------------------------------------------------#
        if (os.path.isfile(path)) & (os.path.getsize(path) > 1000):
            res = True

        #------------------------------------------------------------------------------------#
        #The following will read the file back in and check the different values are the same.
        #------------------------------------------------------------------------------------#
        self.batch_file = open(path, 'r')
        self.assertFalse(self.batch_file.closed)

        for line in self.batch_file:
            if '=' in line:
                key, val = line.split('=')
                self.key_array.append(key)
                self.val_array.append(val)

        self.batch_file.close()
        self.assertTrue(self.batch_file.closed)


    def test_write_batch_to_file_batch_name(self):
        i = 0
        for key in self.key_array:
            self.val_array[i] = self.val_array[i].rstrip()
            if 'batch_name' in key:
                self.assertEqual(self.val_array[i], self.setUp.batch_name)
                break
            i += 1

    def test_write_batch_to_file_p_list(self):
        i = 0
        for key in self.key_array:
            self.val_array[i] = self.val_array[i].rstrip()
            if 'p_list' in key:
                val = map(float, self.val_array[i].split(','))
                self.assertSequenceEqual(val, self.gui_batch.p_values)
                break
            i += 1

    def test_write_batch_to_file_x_list(self):
        i = 0
        for key in self.key_array:
            self.val_array[i] = self.val_array[i].rstrip()
            if 'x_list' in key:
                val = float(self.val_array[i])
                self.assertEqual(val, self.gui_batch.x_value)
                break
            i += 1

    def test_write_batch_to_file_y_list(self):
        i = 0
        for key in self.key_array:
            self.val_array[i] = self.val_array[i].rstrip()
            if 'y_list' in key:
                val = float(self.val_array[i])
                self.assertEqual(val, self.gui_batch.y_value)
                break
            i += 1

    def test_write_batch_to_file_g_list(self):
        i = 0
        for key in self.key_array:
            self.val_array[i] = self.val_array[i].rstrip()
            if 'g_list' in key:
                val = float(self.val_array[i])
                self.assertEqual(val, self.gui_batch.g_value)
                break
            i += 1

    def test_write_batch_to_file_s_list(self):
        i = 0
        for key in self.key_array:
            self.val_array[i] = self.val_array[i].rstrip()
            if 's_list' in key:
                val = float(self.val_array[i])
                self.assertEqual(val, self.gui_batch.s_value)
                break
            i += 1

    def test_write_batch_to_file_z_list(self):
        i = 0
        for key in self.key_array:
            self.val_array[i] = self.val_array[i].rstrip()
            if 'z_list' in key:
                val = float(self.val_array[i])
                self.assertEqual(val, self.gui_batch.z_value)
                break
            i += 1

    def test_write_batch_to_file_wavelength(self):
        i = 0
        for key in self.key_array:
            self.val_array[i] = self.val_array[i].rstrip()
            if 'wavelengths' in key:
                val = map(float, self.val_array[i].split(','))
                self.assertListEqual(val, self.gui_batch.wavelength_values)
                break
            i += 1

    def test_write_batch_to_file_verbose(self):
        i = 0
        for key in self.key_array:
            self.val_array[i] = self.val_array[i].rstrip()
            if 'verbose' in key:
                val = float(self.val_array[i])
                self.assertEqual(val, self.gui_batch.verbose_value)
                break
            i += 1

    def test_write_batch_to_file_num_cpu(self):
        i = 0
        for key in self.key_array:
            self.val_array[i] = self.val_array[i].rstrip()
            if 'num_cpus' in key:
                val = float(self.val_array[i])
                self.assertEqual(val, self.gui_batch.nb_cpu)
                break
            i += 1

    def test_write_batch_to_file_exec_path(self):
        i = 0
        for key in self.key_array:
            self.val_array[i] = self.val_array[i].rstrip()
            if 'exec_path' in key:
                val = float(self.val_array[i])
                self.assertEqual(val, self.gui_batch.exec_path)
                break
            i += 1

    def test_write_batch_to_file_pytho_path(self):
        i = 0
        for key in self.key_array:
            self.val_array[i] = self.val_array[i].rstrip()
            if 'phytoplankton_absorption_file' in key:
                val = float(self.val_array[i])
                self.assertEqual(val, self.gui_batch.phyto_path)
                break
            i += 1

    def test_write_batch_to_file_bottom_path(self):
        i = 0
        for key in self.key_array:
            self.val_array[i] = self.val_array[i].rstrip()
            if 'bottom_reflectance_file' in key:
                val = float(self.val_array[i])
                self.assertEqual(val, self.gui_batch.bottom_path)
                break
            i += 1

    def test_write_batch_to_file_saa_values(self):
        i = 0
        for key in self.key_array:
            self.val_array[i] = self.val_array[i].rstrip()
            if 'saa_values' in key:
                val = float(self.val_array[i])
                self.assertEqual(val, self.gui_batch.saa_values)
                break
            i += 1

    def test_write_batch_to_file_sza_values(self):
        i = 0
        for key in self.key_array:
            self.val_array[i] = self.val_array[i].rstrip()
            if 'sza_values' in key:
                val = float(self.val_array[i])
                self.assertEqual(val, self.gui_batch.sza_values)
                break
            i += 1

    def test_write_batch_to_file_report_parameter(self):
        i = 0
        for key in self.key_array:
            self.val_array[i] = self.val_array[i].rstrip()
            if 'report_parameter' in key:
                val = float(self.val_array[i])
                self.assertEqual(val, self.gui_batch.report_parameter_value)
                break
            i += 1

def main():
    unittest.main()


if __name__ == '__main__':
    main()


import os
import sys
import time

sys.path.append("../..")

import logger as log
import scipy
from scipy import loadtxt
import libplanarradpy
import libplanarradpy.state
import csv
from multiprocessing import Process

__author__ = 'marrabld'

DEBUG_LEVEL = libplanarradpy.state.State().debug
lg = log.logger
lg.setLevel(DEBUG_LEVEL)


class RunParameters():
    """Run parameters required by PlanarRad

    All parameters are properties of this class
    """

    def __init__(self, wavelengths):
        lg.info('============')
        lg.info('Initialising')
        lg.info('============')

        if not wavelengths:
            self.wavelengths = scipy.linspace(410.0, 730.0, 17)
        else:
            self.wavelengths = scipy.fromstring(wavelengths, dtype=float, sep=',')

        self.a = scipy.zeros_like(self.wavelengths)  # total absorption
        self.a_phi = scipy.zeros_like(self.wavelengths)
        self.a_water = scipy.zeros_like(self.wavelengths)
        self.a_cdom = scipy.zeros_like(self.wavelengths)  # CDOM absorption
        self.bb = scipy.zeros_like(self.wavelengths)  # backscatter
        self.bbp = scipy.zeros_like(self.wavelengths)  # particulate scatter
        self.b_water = scipy.zeros_like(self.wavelengths)
        self.b = scipy.zeros_like(self.wavelengths)  # scatter
        self.c = scipy.zeros_like(self.wavelengths)  # attenuation
        self.iop_backscatter_proportion_list = ''  # scipy.asarray([])
        self.depth = 5
        self.theta_points = [0, 5, 15, 25, 35, 45, 55, 65, 75, 85, 90, 95, 105, 115, 125, 135, 145, 155, 165, 175, 180]
        #self.input_path = os.path.abspath(os.path.join('..', 'inputs'))
        #self.output_path = os.path.abspath(os.path.join('..', 'outputs'))
        self.input_path = os.path.abspath(os.path.join('.', 'inputs'))
        self.output_path = os.path.abspath(os.path.join('.', 'outputs'))
        self.pure_water_absorption_file = os.path.abspath(
            os.path.join(os.path.join(self.input_path, 'iop_files'), 'a_water.csv'))
        self.pure_water_scattering_file = os.path.abspath(
            os.path.join(os.path.join(self.input_path, 'iop_files'), 'b_water.csv'))
        self.phytoplankton_absorption_file = os.path.abspath(
            os.path.join(os.path.join(self.input_path, 'iop_files'), 'a_phi.csv'))
        self.project_file = os.path.abspath(os.path.join(os.path.join(self.input_path, 'batch_files'), 'batch_run.txt'))
        self.attenuation_file = os.path.abspath(
            os.path.join(os.path.join(self.input_path, 'iop_files'), 'bz052_c17.txt'))
        self.absorption_file = os.path.abspath(os.path.join(os.path.join(self.input_path, 'iop_files'), 'batch_a.txt'))
        self.scattering_file = os.path.abspath(
            os.path.join(os.path.join(self.input_path, 'iop_files'), 'bz052_b17.txt'))
        self.sky_azimuth = 50
        self.sky_zenith = 45
        self.euler_steps_per_optical_depth = 100
        self.integrator = 'runga4'
        self.iop_type = 'petzold'
        self.sample_point_distance = 1
        self.sample_point_delta_distance = 0.01
        self.bottom_reflectance_file = os.path.abspath(
            os.path.join(os.path.join(self.input_path, 'bottom_files'), 'ger_sand17.txt'))
        self.sky_type = 'hlideal'
        self.sky_c = 1
        self.sky_r_dif = 0.3
        self.iface_type = 'coxmunk'
        self.ds_name = 'HL Standard'
        self.vn = 18
        self.hn = 24
        self.num_bands = self.wavelengths.shape[0]
        self.sky_state = 'clear'
        self.surf_state = 'flat'
        self.ds_code = 'HL_' + str(self.vn) + 'x' + str(self.hn)
        self.partition = 'sphere'
        self.sky_file = os.path.abspath(
            os.path.join(os.path.join(self.input_path, 'sky_files'),
                         'sky_' + self.sky_state + '_z' + str(self.sky_zenith) + '_a' + str(
                             self.sky_azimuth) + '_' + str(
                             self.num_bands) + '_' + self.ds_code))
        self.iface_0_ri = 1.34
        self.iface_1_ri = 1.00
        self.bound_bottom_reflec_diffuse_data = 0
        self.sky_sub_quad_count = '1E6'
        self.iface_sub_quad_count = '1E6'
        self.pf_sub_quad_count = '1E4'
        self.midpoint_steps_per_optical_depth = 50
        self.runga4_steps_per_optical_depth = 20
        self.runga4adap_min_steps_per_optical_depth = 5
        self.runga4adap_max_steps_per_optical_depth = 40
        self.runga4adap_min_error = 0.01
        self.runga4adap_max_error = 0.1
        self.ld_b_image_save_file = os.path.join(self.output_path, 'image_Ld_b.ppm')
        self.ld_b_image_sens_k = 0.0008
        self.ld_b_save_file = os.path.join(self.output_path, 'Ld_b_data')
        self.verbose = 6
        self.num_cpus = -1
        self.wind_speed = 5
        self.crosswind_vertices = 100
        self.upwind_vertices = 100
        self.surface_size = 1
        self.surface_radius = 0.5
        self.target_size = 0.2
        self.rays_per_quad = 10
        self.surface_count = 200
        self.azimuthally_average = 'yes'
        self.water_surface_file = os.path.abspath(
            os.path.join(os.path.join(self.input_path, 'surface_files'),
                         'sf_' + self.iface_type + '_w' + str(self.wind_speed) + '_r' + str(
                             self.rays_per_quad) + '_s' + \
                         str(self.surface_count) + '_' + self.azimuthally_average + '_mono_' + self.ds_code))
        self.wind_direc = 0
        self.crosswind_vertices = 100
        self.model_eqn = 'clear'
        self.phase_function_file = os.path.abspath(
            os.path.join(os.path.join(self.input_path, 'phase_files'), 'pf_' + self.iop_type + '_mono_' + self.ds_code))
        self.exec_path = '/usr/bin/jude_test/bin/'
        self.report_file = os.path.join(self.output_path, 'batch_run_report.txt\n')

    def write_run_parameters_to_file(self):
        """All of the class properties are written to a text file

        Each property is on a new line with the key and value seperated with an equals sign '='
        This is the mane planarrad properties file used by slabtool
        """

        self.update_filenames()

        lg.info('Writing Inputs to file : ' + self.project_file)

        # First update the file names in case we changed the file values.  the file name includes the file values
        # self.updateFileNames()

        f = open(self.project_file, 'w')

        f.write('name = ' + self.project_file + '\n')
        f.write('band_count = ' + str(len(self.wavelengths)) + '\n')
        f.write('bs_name = ' + str(len(self.wavelengths)) + ' Bands (' + str(self.wavelengths[0]) + '-' + str(
            self.wavelengths[len(self.wavelengths) - 1]) + ' nm) \n')
        f.write('bs_code = ' + str(len(self.wavelengths)) + '\n')
        f.write('band_centres_data = ')
        f.write(",".join([str(wave) for wave in self.wavelengths]) + '\n')
        # f.write('band_widths_data = ')
        # for i in range(0, len(self.wavelengths) - 1):  # Find better way to do this!
        # width = self.wavelengths[i + 1] - self.wavelengths[i]
        #     f.write(str(width))
        #     if i < len(self.wavelengths) - 2:
        #         f.write(',')
        f.write('\n')
        f.write('ds_name = ' + self.ds_name + '\n')
        f.write('ds_code = ' + self.ds_code + '\n')
        f.write('partition = ' + self.partition + '\n')
        f.write('vn = ' + str(self.vn) + '\n')
        f.write('hn = ' + str(self.hn) + '\n')
        f.write('theta_points=')
        f.write(",".join([str(theta) for theta in self.theta_points]) + '\n')
        f.write('depth = ' + str(self.depth) + '\n')
        f.write('sample_point_distance = ' + str(self.sample_point_distance) + '\n')
        f.write('sample_point_delta_distance = ' + str(self.sample_point_delta_distance) + '\n')
        f.write('\n')
        f.write('sky_fp = ' + self.sky_file + '\n')  # need to create these files from sky tool
        f.write('water_surface_fp =' + self.water_surface_file)
        f.write('\n')
        f.write('atten_fp = ' + self.attenuation_file + '\n')
        f.write('scat_fp = ' + self.scattering_file + '\n')
        f.write('pf_fp = ' + self.phase_function_file + '\n')
        f.write('bottom_reflec_diffuse_fp = ' + self.bottom_reflectance_file + '\n')
        f.write('sky_type = ' + self.sky_type + '\n')
        f.write('sky_azimuth = ' + str(self.sky_azimuth) + '\n')
        f.write('sky_zenith = ' + str(self.sky_zenith) + '\n')
        f.write('sky_C = ' + str(self.sky_c) + '\n')
        f.write('sky_rdif = ' + str(self.sky_r_dif) + '\n')
        f.write('iface_type = ' + self.iface_type + '\n')
        f.write('iface_refrac_index_0 = ' + str(self.iface_0_ri) + '\n')
        f.write('iface_refrac_index_1 = ' + str(self.iface_1_ri) + '\n')
        #        f.write('iop_atten_data = 1\n')
        #        f.write('iop_absorp_data = 0\n')
        f.write('iop_type = ' + self.iop_type + '\n')
        f.write('iop_backscatter_proportion_list = ' + str(self.iop_backscatter_proportion_list) + '\n')
        f.write('bound_bottom_reflec_diffuse_data = ' + str(self.bound_bottom_reflec_diffuse_data) + '\n')
        f.write('sky_sub_quad_count = ' + self.sky_sub_quad_count + '\n')
        f.write('iface_sub_quad_count = ' + self.iface_sub_quad_count + '\n')
        f.write('pf_sub_quad_count = ' + self.pf_sub_quad_count + '\n')
        f.write('integrator = ' + self.integrator + '\n')
        f.write('euler_steps_per_optical_depth = ' + str(self.euler_steps_per_optical_depth) + '\n')
        f.write('midpoint_steps_per_optical_depth = ' + str(self.midpoint_steps_per_optical_depth) + '\n')
        f.write('runga4_steps_per_optical_depth = ' + str(self.runga4_steps_per_optical_depth) + '\n')
        f.write('runga4adap_min_steps_per_optical_depth = ' + str(self.runga4adap_min_steps_per_optical_depth) + '\n')
        f.write('runga4adap_max_steps_per_optical_depth = ' + str(self.runga4adap_max_steps_per_optical_depth) + '\n')
        f.write('runga4adap_min_error = ' + str(self.runga4adap_min_error) + '\n')
        f.write('runga4adap_max_error = ' + str(self.runga4adap_max_error) + '\n')
        f.write('\n')

        f.write('Ld_b_image_save_fp = ' + os.path.join(self.output_path,
                                                       'image_Ld_b.ppm') + '\n')  #todo update this in the constructor not here

        f.write('Ld_b_image_sens_k = ' + str(self.ld_b_image_sens_k) + '\n')
        f.write('\n')
        f.write('Ld_b_save_fp = ' + os.path.join(self.output_path,
                                                 'Ld_b_data') + '\n')
        f.write('\n')
        f.write('report_save_fp = ' + self.report_file)
        f.write('\n')
        f.write('verbose = ' + str(self.verbose) + '\n')
        f.close()

    def write_sky_params_to_file(self):
        """Writes the params to file that skytool_Free needs to generate the sky radiance distribution."""

        inp_file = self.sky_file + '_params.txt'
        lg.info('Writing Inputs to file : ' + inp_file)

        f = open(inp_file, 'w')

        f.write('verbose= ' + str(self.verbose) + '\n')
        f.write('band_count= ' + str(self.num_bands) + '\n')
        f.write('band_centres_data= ')
        f.write(",".join([str(wave) for wave in self.wavelengths]) + '\n')
        f.write('partition= ' + self.partition + '\n')
        f.write('vn= ' + str(self.vn) + '\n')
        f.write('hn= ' + str(self.hn) + '\n')
        f.write('rdif= ' + str(self.sky_r_dif) + '\n')
        f.write('theta_points= ')
        f.write(",".join([str(theta) for theta in self.theta_points]) + '\n')
        f.write('type= ' + self.sky_type + '\n')
        f.write('azimuth= ' + str(self.sky_azimuth) + '\n')
        f.write('zenith= ' + str(self.sky_zenith) + '\n')
        f.write('sky_save_fp= ' + inp_file.strip('_params.txt') + '\n')
        f.write('sky_image_save_fp= ' + self.sky_file + '.ppm' + '\n')
        f.write('sky_image_size= 256' + '\n')
        if self.sky_type == 'hlideal':
            f.write('C= ' + str(self.sky_c) + '\n')
            f.write('rdif= ' + str(self.sky_r_dif) + '\n')
        f.flush()
        f.close()

    def write_surf_params_to_file(self):
        """Write the params to file that surftool_Free needs to generate the surface facets"""

        inp_file = self.water_surface_file + '_params.txt'
        lg.info('Writing Inputs to file : ' + inp_file)

        if self.surf_state == 'flat':  # this is the only one that currently works.
            lg.info('Surface Type is :: flat')
            f = open(inp_file, 'w')

            f.write('verbose= ' + str(self.verbose) + '\n')
            f.write('band_count= ' + str(self.num_bands) + '\n')
            f.write('band_centres_data= ')
            f.write(",".join([str(wave) for wave in self.wavelengths]) + '\n')
            f.write('partition= ' + self.partition + '\n')
            f.write('vn= ' + str(self.vn) + '\n')
            f.write('hn= ' + str(self.hn) + '\n')
            f.write('theta_points= ')
            f.write(",".join([str(theta) for theta in self.theta_points]) + '\n')
            f.write('type= ' + self.iface_type + '\n')
            f.write('refrac_index_0= ' + str(self.iface_0_ri) + '\n')
            f.write('refrac_index_1= ' + str(self.iface_1_ri) + '\n')
            f.write('wind_speed= ' + str(self.wind_speed) + '\n')
            f.write('wind_direc= ' + str(self.wind_direc) + '\n')
            f.write('crosswind_vertices= ' + str(self.crosswind_vertices) + '\n')
            f.write('upwind_vertices= ' + str(self.upwind_vertices) + '\n')
            f.write('surface_size= ' + str(self.surface_size) + '\n')
            f.write('surface_radius=' + str(self.surface_radius) + '\n')
            f.write('target_size= ' + str(self.target_size) + '\n')
            f.write('rays_per_quad= ' + str(self.rays_per_quad) + '\n')
            f.write('surface_count= ' + str(self.surface_count) + '\n')
            f.write('azimuthally_average= ' + str(self.azimuthally_average) + '\n')
            f.write('surface_save_fp= ' + inp_file.strip('_params.txt') + '\n')
            f.flush()
            f.close()

    def write_phase_params_to_file(self):
        """Write the params to file that surftool_Free needs to generate the surface facets"""
        inp_file = os.path.join(os.path.join(self.input_path, 'phase_files'), self.phase_function_file) + '_params.txt'
        lg.info('Writing Inputs to file : ' + inp_file)

        if self.iop_type == 'isotropic' or 'isotropic_integ' or 'petzold' or 'pure_water ':
            lg.info('Iop type is :: ' + self.iop_type)

            f = open(inp_file, 'w')

            f.write('verbose = ' + str(self.verbose) + '\n')
            f.write('band_count = ' + str(self.num_bands) + '\n')
            f.write('band_centres_data = ')
            f.write(",".join([str(wave) for wave in self.wavelengths]) + '\n')
            f.write('partition = ' + self.partition + '\n')
            f.write('vn = ' + str(self.vn) + '\n')
            f.write('hn = ' + str(self.hn) + '\n')
            f.write('theta_points = ')
            f.write(",".join([str(theta) for theta in self.theta_points]) + '\n')
            f.write('type = ' + self.iop_type + '\n')
            f.write('phase_func_save_fp = ' + inp_file.strip('_params.txt') + '\n')
            f.flush()
            f.close()

    def update_filenames(self):
        """Does nothing currently.  May not need this method"""
        self.sky_file = os.path.abspath(os.path.join(os.path.join(self.input_path, 'sky_files'),
                                                     'sky_' + self.sky_state + '_z' + str(
                                                         self.sky_zenith) + '_a' + str(
                                                         self.sky_azimuth) + '_' + str(
                                                         self.num_bands) + '_' + self.ds_code))


class BioOpticalParameters():
    """Contains useful parameters and methods for modelling IOPs using bio-optical models

    Constructor takes wavelengths.  This is a common wavelength that all IOPs will be interpolated to
    """

    def __init__(self, wavelengths):
        """Constructor

        :param wavelengths: list of wavelengths all IOPs will be interpolated to
        """
        self.wavelengths = scipy.asarray([wavelengths])
        self.b_bp = scipy.asarray([])
        self.a_cdom = scipy.asarray([])
        self.a_phi = scipy.asarray([])
        self.a_water = scipy.asarray([])
        self.b_water = scipy.asarray([])

        self.b_b = scipy.asarray([])
        self.b = scipy.asarray([])
        self.a = scipy.asarray([])
        self.c = scipy.asarray([])


    def build_bbp(self, x, y, wave_const=550):
        """
        Builds the particle backscattering function  :math:`X(\\frac{550}{\\lambda})^Y`

        :param x: function coefficient
        :param y: order of the power function
        :param wave_const: wave constant default 550 (nm)
        :returns null:
        """
        lg.info('Building b_bp spectra')
        self.b_bp = x * (wave_const / self.wavelengths) ** y

    def build_a_cdom(self, g, s, wave_const=400):
        """
        Builds the CDOM absorption function :: :math:`G \exp (-S(\lambda - 400))`

        :param g: function coefficient
        :param s: slope factor
        :param wave_const: wave constant default = 400 (nm)
        :returns null:
        """
        lg.info('building CDOM absorption')
        self.a_cdom = g * scipy.exp(-s * (self.wavelengths - wave_const))

    def read_aphi_from_file(self, file_name):
        """Read the phytoplankton absorption file from a csv formatted file

        :param file_name: filename and path of the csv file
        """
        lg.info('Reading ahpi absorption')
        try:
            self.a_phi = self._read_iop_from_file(file_name)
        except:
            lg.exception('Problem reading file :: ' + file_name)
            self.a_phi = -1

    def scale_aphi(self, scale_parameter):
        """Scale the spectra by multiplying by linear scaling factor

        :param scale_parameter: Linear scaling factor
        """
        lg.info('Scaling a_phi by :: ' + str(scale_parameter))
        try:
            self.a_phi = self.a_phi * scale_parameter
        except:
            lg.exception("Can't scale a_phi, check that it has been defined ")

    def read_pure_water_absorption_from_file(self, file_name):
        """Read the pure water absorption from a csv formatted file

        :param file_name: filename and path of the csv file
        """
        lg.info('Reading water absorption from file')
        try:
            self.a_water = self._read_iop_from_file(file_name)
        except:
            lg.exception('Problem reading file :: ' + file_name)


    def read_pure_water_scattering_from_file(self, file_name):
        """Read the pure water scattering from a csv formatted file

        :param file_name: filename and path of the csv file
        """
        lg.info('Reading water scattering from file')
        try:
            self.b_water = self._read_iop_from_file(file_name)
        except:
            lg.exception('Problem reading file :: ' + file_name)


    def _read_iop_from_file(self, file_name):
        """
        Generic IOP reader that interpolates the iop to the common wavelengths defined in the constructor

        :param file_name: filename and path of the csv file
        :returns interpolated iop
        """
        lg.info('Reading :: ' + file_name + ' :: and interpolating to ' + str(self.wavelengths))

        if os.path.isfile(file_name):
            iop_reader = csv.reader(open(file_name), delimiter=',', quotechar='"')
            wave = iop_reader.next()
            iop = iop_reader.next()
        else:
            lg.exception('Problem reading file :: ' + file_name)
            raise IOError

        try:
            return scipy.interp(self.wavelengths, wave, iop)
        except IOError:
            lg.exception('Error interpolating IOP to common wavelength')
            return -1

    def write_b_to_file(self, file_name):
        """Write the total scattering to csv file

        :param file_name: filename and path of the csv file
        """
        self._write_iop_to_file(self.b, file_name)

    def write_c_to_file(self, file_name):
        """Write the total attentuation to file

        :param file_name: filename and path of the csv file
        """
        self._write_iop_to_file(self.c, file_name)

    def _write_iop_to_file(self, iop, file_name):
        """Generic iop file writer

        :param iop numpy array to write to file
        :param file_name the file and path to write the IOP to
        """
        lg.info('Writing :: ' + file_name)
        f = open(file_name, 'w')
        for i in scipy.nditer(iop):
            f.write(str(i) + '\n')

    def build_bb(self):
        """Calculates the total backscattering


        """
        lg.info('Building bb spectra')
        self.b_b = self.b_bp  # + b_bphi

    def build_b(self, scattering_fraction=0.01833):
        """Calculates the total scattering from back-scattering

        :param scattering_fraction: the fraction of back-scattering to total scattering default = 0.01833
        """
        lg.info('Building b with scattering fraction of :: ' + str(scattering_fraction))
        self.b = (self.b_b + self.b_water / 2.0) / scattering_fraction

    def build_a(self):
        """Calculates the total absorption from water, phytoplankton and CDOM

        a = awater + acdom + aphi
        """
        lg.info('Building total absorption')
        self.a = self.a_water + self.a_cdom + self.a_phi

    def build_c(self):
        """Calculates the total attenuation from the total absorption and total scattering

        c = a + b
        """
        lg.info('Building total attenuation C')
        self.c = self.a + self.b

    def build_all_iop(self):
        """Meta method that calls all of the build methods in the correct order

        self.build_a()
        self.build_bb()
        self.build_b()
        self.build_c()
        """
        lg.info('Building all b and c from IOPs')

        self.build_a()
        self.build_bb()
        self.build_b()
        self.build_c()


class BatchRun():
    """This class is used for batch running PlanarRad for many different IOPs.

    It will also distribute the work over many CPUs.  It will run an single instance for PlanarRad on each available
    cores or the number of cores defined in the batchrun file.

    Available 'batchable' parameters are: \n
    Sun Azimuth Angle (deg) [saa] \n
    Sun Zenith Angle (deg) [sza] \n
    Phytoplankton scaling parameter [p] \n
    particulate scattering parameters [x, y] see BioOpticalParameters \n
    CDOM absorption parameters [g, s] \n
    depth (m) [z]
    """

    def __init__(self, object, batch_name='batch'):
        """Construcuter that sets the up batch run with 'batchable' parameters

        :param batch_name: the name of the project.  All outputs will be put in a directory of the same name
        """
        self.run_params = object
        self.saa_list = []
        self.sza_list = []
        self.p_list = []  # Phyto scaling param
        self.x_list = []
        self.y_list = []
        self.g_list = []
        self.s_list = []
        self.z_list = []

        self.batch_output = os.path.join(self.run_params.output_path, batch_name)
        self.bio_params = BioOpticalParameters(self.run_params.wavelengths)

    def run(self):
        """Distributes the work across the CPUs.  It actually uses _run()"""
        done = False
        dir_list = []
        tic = time.clock()
        lg.info('Starting batch run at :: ' + str(tic))

        if self.run_params.num_cpus == -1:  # user hasn't set a throttle
            self.run_params.num_cpus = os.sysconf("SC_NPROCESSORS_ONLN")
            lg.info('Found ' + str(self.run_params.num_cpus) + ' CPUs')

        # --------------------------------------------------#
        # COUNT THE NUMBER OF DIRECTORIES TO ITERATE THROUGH
        # --------------------------------------------------#
        tmp_dir_list = os.listdir(self.batch_output)
        for direc in tmp_dir_list:
            dir_list.append(os.path.join(self.batch_output, direc))

        num_dirs = len(dir_list)
        lg.info('Found ' + str(num_dirs) + ' directories to process in ' + self.batch_output)

        sub = scipy.floor(num_dirs / self.run_params.num_cpus)
        remainder = num_dirs - (sub * self.run_params.num_cpus)
        if remainder > 0:
            lg.warning('Number of variations not evenly divisible by number of CPUs')
            lg.warning('This is not a problem, last block will not use all available CPUs')
            lg.warning('The remainder is :: ' + str(remainder))

        while not done:
            for l in range(0, int(sub)):
                lg.info('Starting processing block of :: ' + str(self.run_params.num_cpus) + ' processes')

                for m in range(0, self.run_params.num_cpus):
                    #row = (m * sub) + l
                    _dir = dir_list.pop()

                    #--------------------------------------------------#
                    # CHECK TO SEE IF REPORT HAS BEEN GENERATED AND DON'T
                    # BOTHER RUNNING AGAIN IF THEY DO EXIST
                    #--------------------------------------------------#

                    report_dir, report_file_name = os.path.split(self.run_params.report_file)
                    lg.debug(report_file_name)
                    lg.debug(os.path.join(_dir, report_file_name))

                    try:
                        rep_size = os.path.getsize(os.path.join(_dir, report_file_name.strip('\n')))
                        lg.debug('report size is :: ' + str(rep_size))
                    except:
                        rep_size = 0

                    if rep_size < 1.0:  # TODO this is a spoof!
                        lg.info('No report file found, running process')
                        p = Process(target=self._run, args=(_dir,))
                    else:
                        lg.warning('Report file found :: ' + os.path.join(_dir, report_file_name.strip(
                            '\n')) + ' not redoing run ')
                        p = Process(target=self._dummy, args=(_dir,))

                    # !! for testing
                    #p = Process(target=self._dummy, args=(_dir,))
                    p.start()
                    lg.info('Starting Process :: Process ID :: ' + str(p.pid))

                p.join()

            self.run_params.num_cpus = remainder
            remainder = 0
            lg.info('Processing remainder')
            sub = 1
            if remainder == 0:
                done = True

        toc = time.clock()  # this isn't working
        lg.info('Ending batch run at :: ' + str(toc))
        timeTaken = toc - tic
        lg.info('Time taken ::' + str(timeTaken))

    def _dummy(self, run_dir):
        """This is just for spoofing the batch.  Doesn't run anything"""
        lg.debug(run_dir)

    def _run(self, run_dir):
        """Distributed process"""

        # Check to see if the required run_params files exist, if they dont use the tools to generate them

        # --------------------------------------------------#
        # HERE WE RECREATE OUR RUN_PARAMS OBJECT FROM
        # THE RUN FILE WE WROTE TO DISK EARLIER
        # --------------------------------------------------#
        file_tools = FileTools()
        run_dict = file_tools.read_param_file_to_dict(os.path.join(run_dir, 'batch.txt'))
        #print(run_dict['band_centres_data'])

        #self.run_params.wavelengths = run_dict['wavelengths']
        #run_params = RunParameters()
        #run_params = file_tools.dict_to_object(run_params, run_dict)
        #------------------------------------------------#
        # Sky inputs
        #------------------------------------------------#
        #lg.debug(run_dict.keys())
        #self.run_params.update_filenames()
        #lg.debug('!!!!!!!!!' + run_dict['sky_fp'])
        if os.path.isfile(run_dict['sky_fp']):
            sky_file_exists = True
            lg.info('Found sky_tool generated file' + run_dict['sky_fp'])
        else:
            lg.info('No sky_tool generated file, generating one')
            #try:
            inp_file = run_dict['sky_fp'] + '_params.txt'
            #self.run_params.sky_file = inp_file
            self.run_params.write_sky_params_to_file()
            #if not os.path.isfile(inp_file):
            #    lg.error(inp_file + ' : is not a valid parameter file')
            lg.debug('Runing skytool' + os.path.join(self.run_params.exec_path, 'skytool_free') + '#')
            lg.debug(os.path.join(self.run_params.exec_path, 'skytool_free') + ' params=' + inp_file)
            os.system(os.path.join(self.run_params.exec_path, 'skytool_free') + ' params=' + inp_file)
            #except OSError:
            #    lg.exception('Cannot execute PlannarRad, cannot find executable file to skytool_free')

        #------------------------------------------------#
        # Water surface inputs
        #------------------------------------------------#
        if os.path.isfile(run_dict['water_surface_fp']):
            surface_file_exists = True
            lg.info('Found surf_tool generated file' + run_dict['water_surface_fp'])
        else:
            lg.info('No surf_tool generated file, generating one')
            try:
                inp_file = run_dict['water_surface_fp'] + '_params.txt'
                self.run_params.write_surf_params_to_file()
                if not os.path.isfile(inp_file):
                    lg.error(inp_file + ' : is not a valid parameter file')
                os.system(os.path.join(self.run_params.exec_path, 'surftool_free') + ' params=' + inp_file)
            except OSError:
                lg.exception('Cannot execute PlannarRad, cannot find executable file to surftool_free')

        #------------------------------------------------#
        # Phase functions inputs
        #------------------------------------------------#
        if os.path.isfile(run_dict['pf_fp']):
            phase_file_exists = True
            lg.info('Found phase_tool generated file' + run_dict['pf_fp'])
        else:
            lg.info('No sky_tool generated file, generating one')
            try:
                inp_file = run_dict['pf_fp'] + '_params.txt'
                self.run_params.write_phase_params_to_file()
                if not os.path.isfile(inp_file):
                    lg.error(inp_file + ' : is not a valid parameter file')
                os.system(os.path.join(self.run_params.exec_path, 'phasetool_free') + ' params=' + inp_file)
            except OSError:
                lg.exception('Cannot execute PlannarRad, cannot find executable file to phasetool_free')

        #------------------------------------------------#
        # slabtool inputs [Run planarrad]
        #------------------------------------------------#

        inp_file = run_dict['name']

        if not os.path.isfile(inp_file):
            lg.error(inp_file + ' : is not a valid batch file')

        try:
            os.system(os.path.join(self.run_params.exec_path, 'slabtool_free') + ' params=' + inp_file)
        except OSError:
            lg.exception('Cannot execute PlannarRad, cannot find executable file to slabtool_free')

    def generate_directories(self, overwrite=False):
        """For all possible combinations of 'batchable' parameters. create a unique directory to story outputs

        Each directory name is unique and contains the run parameters in the directory name

        :param overwrite: If set to True will over write all files default = False
        """
        if not os.path.exists(self.batch_output):
            try:
                lg.info('Creating batch project directory')
                if self.batch_output == self.run_params.output_path + 'batch':
                    lg.warning('Using default project name.  Consider renaming!')
                os.makedirs(self.batch_output)
            except OSError:
                lg.exception('Could not create project directory')

        elif os.path.exists(self.batch_output) and overwrite == True:
            try:
                lg.info('Creating batch project directory')
                lg.warning('Overwriting existing directories')
                if self.batch_output == self.run_params.output_path + 'batch':
                    lg.warning('Using default project name.  Consider renaming!')
                os.makedirs(self.batch_output)
            except OSError:
                lg.exception('Could not create project directory')



        # --------------------------------------------------#
        # GENERATE ALL THE IOPS FROM BIOP
        # --------------------------------------------------#

        #--------------------------------------------------#
        # WRITE EACH BIOP TO CSV FILE INTO THE INPUT
        # DIRECTORY IF IT DOESNT EXIST
        #--------------------------------------------------#

        #--------------------------------------------------#
        # GENERATE A LIST OF ALL COMBINATIONS OF BIOPS
        #--------------------------------------------------#

        #--------------------------------------------------#
        # WRITE THE DIRECTORIES FOR EACH BIOP AND NAME APPROPRIATELY
        # DON'T OVERWRITE IF THEY EXIST ALREADY
        #--------------------------------------------------#

        self.bio_params.read_pure_water_absorption_from_file(
            self.run_params.pure_water_absorption_file)
        self.bio_params.read_pure_water_scattering_from_file(
            self.run_params.pure_water_scattering_file)
        self.bio_params.read_aphi_from_file(self.run_params.phytoplankton_absorption_file)

        for saa in self.saa_list:
            # update the saa in the run file & the todo filename!
            self.run_params.sky_aziumth = saa
            self.run_params.sky_file = os.path.abspath(
                os.path.join(os.path.join(self.run_params.input_path, 'sky_files'),
                             'sky_' + self.run_params.sky_state + '_z' + str(self.run_params.sky_zenith) + '_a' + str(
                                 self.run_params.sky_azimuth) + '_' + str(
                                 self.run_params.num_bands) + '_' + self.run_params.ds_code))

            for sza in self.sza_list:
                # update the saz in the run file
                self.run_params.sky_zenith = sza
                self.run_params.sky_file = os.path.abspath(
                    os.path.join(os.path.join(self.run_params.input_path, 'sky_files'),
                                 'sky_' + self.run_params.sky_state + '_z' + str(
                                     self.run_params.sky_zenith) + '_a' + str(self.run_params.sky_azimuth) + '_' + str(
                                     self.run_params.num_bands) + '_' + self.run_params.ds_code))
                for p in self.p_list:
                    for x in self.x_list:
                        for y in self.y_list:
                            for g in self.g_list:
                                for s in self.s_list:
                                    for z in self.z_list:
                                        file_name = 'SAA' + str(saa) + '_SZA' + str(sza) + '_P' + str(p) + '_X' + str(
                                            x) + '_Y' + str(y) + '_G' + str(g) + '_S' + str(s) + '_Z' + str(z)
                                        dir_name = os.path.join(self.batch_output, file_name)
                                        self.run_params.output_path = dir_name
                                        #--------------------------------------------------#
                                        # UPDATE THE IOP PARAMETERS FOR THE RUN FILE
                                        #--------------------------------------------------#
                                        self.run_params.sky_azimuth = saa
                                        self.run_params.sky_zenith = sza
                                        self.run_params.depth = z
                                        self.bio_params.build_bbp(x, y)  # todo add wave const as a kwarg
                                        self.bio_params.build_a_cdom(g, s)
                                        # Need to re-read the file as it was scaled in a the other run!
                                        self.bio_params.read_aphi_from_file(
                                            self.run_params.phytoplankton_absorption_file)
                                        self.bio_params.scale_aphi(p)

                                        self.bio_params.build_all_iop()
                                        self.run_params.scattering_file = os.path.join(
                                            os.path.join(self.run_params.input_path, 'iop_files'), 'b_' + file_name)
                                        self.bio_params.write_b_to_file(self.run_params.scattering_file)

                                        self.run_params.attenuation_file = os.path.join(
                                            os.path.join(self.run_params.input_path, 'iop_files'), 'c_' + file_name)
                                        self.bio_params.write_c_to_file(self.run_params.attenuation_file)

                                        self.run_params.project_file = os.path.join(dir_name, 'batch.txt')
                                        self.run_params.report_file = os.path.join(dir_name, 'report.txt')

                                        self.run_params.write_sky_params_to_file()
                                        self.run_params.write_surf_params_to_file()
                                        self.run_params.write_phase_params_to_file()

                                        if not os.path.exists(dir_name):
                                            try:
                                                lg.info('Creating run directory')
                                                os.makedirs(dir_name)
                                                self.run_params.write_run_parameters_to_file()
                                            except OSError:
                                                lg.exception('Could not create run directory')

                                        elif os.path.exists(dir_name) and overwrite == True:
                                            try:
                                                lg.info('Creating run directory')
                                                lg.warning('Overwriting existing directories')
                                                os.makedirs(dir_name)
                                                self.run_params.write_run_parameters_to_file()
                                            except OSError:
                                                lg.exception('Could not create run directory')
                                                #--------------------------------------------------#
                                                # FIGURE OUT WHICH IOP TO USE FROM THE DIRECTORY NAME
                                                # WRITE THE PARAM FILE IN TO THE DIRECTORY
                                                #--------------------------------------------------#

                                                #--------------------------------------------------#
                                                # MAKE A LIST OF ALL THE DIRECTORIES AND CHECK
                                                # IF THEY HAVE ANY OUTPUTS IN THEM, IF THEY DO THEY
                                                # HAVE BEEN RUN ALREADY.  IF NOT PARSE THAT RUN FILE
                                                # TO PLANARRAD.  THIS MEANS IF IT FALLS OVER THEN THE
                                                # BATCH CAN BE STARTED AGAIN WITHOUT
                                                #--------------------------------------------------#


    def batch_parameters(self, saa, sza, p, x, y, g, s, z):
        """Takes lists for parameters and saves them as class properties

        :param saa: <list> Sun Azimuth Angle (deg)
        :param sza: <list> Sun Zenith Angle (deg)
        :param p: <list> Phytoplankton linear scalling factor
        :param x: <list> Scattering scaling factor
        :param y: <list> Scattering slope factor
        :param g: <list> CDOM absorption scaling factor
        :param s: <list> CDOM absorption slope factor
        :param z: <list> depth (m)"""
        self.saa_list = saa
        self.sza_list = sza
        self.p_list = p
        self.x_list = x
        self.y_list = y
        self.g_list = g
        self.s_list = s
        self.z_list = z


class FileTools():
    """Useful static methods for file mangling"""

    def __init__(self):
        pass

    @staticmethod
    def read_param_file_to_dict(file_name):
        """Loads a text file to a python dictionary using '=' as the delimiter

        :param file_name: the name and path of the text file
        """
        data = loadtxt(file_name, delimiter='=', dtype=scipy.string0)
        data_dict = dict(data)
        for key in data_dict.keys():
            data_dict[key] = data_dict[key].strip()
            data_dict[key.strip()] = data_dict[key]
            del data_dict[key]

        return data_dict

    @staticmethod
    def dict_to_object(data_object, data_dict):
        """Maps a dictionary to an object.  Variable names become the key in the dict

        :param data_object: Is an instantiated class
        :param data_dict: is the python dictionary
        :returns data_object:
        """
        data_object.__dict__ = data_dict
        return data_object


class HelperMethods():
    """Useful static methods"""

    def __init__(self):
        pass

    @staticmethod
    def string_to_float_list(string_var):
        """Pull comma separated string values out of a text file and converts them to float list"""
        try:
            return [float(s) for s in string_var.strip('[').strip(']').split(', ')]
        except:
            return [float(s) for s in string_var.strip('[').strip(']').split(',')]


class ReportTools():
    """Load the report in to a dictionary"""

    def __init__(self):
        self.data_dictionary = {}

    def read_pr_report(self, filename):
        """Reads in a PlanarRad generated report

        Saves the single line reported parameters as a python dictionary

        :param filename: The name and path of the PlanarRad generated file
        :returns self.data_dictionary: python dictionary with the key and values from the report
        """
        done = False
        f = open(filename)
        while f:
        #for line in open(filename):
            line = f.readline()
            if not line:
                done = True
                break

            if "# Quad solid angle mean point theta table (rows are horizontal, columns are vertical):" in line.strip():
                # read in the bunch of lines.
                tmp = []
                for i_iter in range(0, len(self.data_dictionary['theta_points_deg']) - 2):
                    tmp.append(f.readline())

                self.data_dictionary['Quad_solid_angle_mean_point_theta'] = tmp

            elif '#' not in line or not line.strip():
                element = line.split(',')
                self.data_dictionary[element[0]] = element[1:]

            if "# Quad solid angle mean point phi table (rows are horizontal, columns are vertical):" in line.strip():
                # read in the bunch of lines.
                tmp = []
                for i_iter in range(0, len(self.data_dictionary['theta_points_deg']) - 2):
                    tmp.append(f.readline())

                self.data_dictionary['Quad_solid_angle_mean_point_phi'] = tmp

            elif '#' not in line or not line.strip():
                element = line.split(',')
                self.data_dictionary[element[0]] = element[1:]

            if "L_w band" in line.strip():

                for i_iter in range(0, int(self.data_dictionary['band_count'][1])):
                    tmp = []
                    for j_iter in range(0, len(self.data_dictionary['theta_points_deg']) - 2):
                        tmp.append(f.readline())

                    self.data_dictionary['L_w_band_' + str(i_iter + 1)] = tmp
                    f.readline()
                    f.readline()  # skip the next 2 lines

            if "L_it band" in line.strip():

                for i_iter in range(0, int(self.data_dictionary['band_count'][1])):
                    tmp = []
                    for j_iter in range(0, len(self.data_dictionary['theta_points_deg']) - 2):
                        tmp.append(f.readline())

                    self.data_dictionary['L_it_band_' + str(i_iter + 1)] = tmp
                    f.readline()
                    f.readline()  # skip the next 2 lines




        return self.data_dictionary

    def get_parameter(self, parameter):
        pass

    def calc_directional_aop(self, report, parameter, parameter_dir):
        """
        Will calcuate the directional AOP (only sub-surface rrs for now) if the direction is defined using @
        e.g. rrs@32.0:45  where <zenith-theta>:<azimuth-phi>

        :param report: The planarrad report dictionary.  should include the quadtables and the directional info
        :param parameter: parameter to calc.  Currently only sub-surface reflectance rrs.
        :return:
        """
        lg.debug('calculating the directional ' + parameter)
        tmp_zenith = []

        param_zenith = parameter_dir.split(':')[0]
        param_azimuth = parameter_dir.split(':')[1]

        # --------------------------------------------------#
        # find the mean directions values
        # --------------------------------------------------#
        for i_iter in range(0, int(report['vn'][1])):
            tmp_zenith.append(report['Quad_solid_angle_mean_point_theta'][i_iter][:].split(',')[0]) #that was a pain!

        tmp_azimuth = report['Quad_solid_angle_mean_point_phi'][1]
        zenith = scipy.asarray(tmp_zenith, dtype=float)
        azimuth = scipy.fromstring(tmp_azimuth, dtype=float, sep=',')

        # --------------------------------------------------#
        # now grab the min and max index of the closest match
        # --------------------------------------------------#
        #min_zenith_idx = (scipy.abs(zenith - param_zenith)).argmin()

        from scipy import interpolate


        lw = scipy.zeros(int(report['band_count'][1]))

        for j_iter in range(0, int(report['band_count'][1])):

            if parameter == 'rrs':
                lg.info('Calculating directional rrs')
                tmp_lw = report['L_w_band_' + str(j_iter + 1)]
            elif parameter == 'Rrs':
                lg.info('Calculating directional Rrs')
                print(report.keys())
                tmp_lw = report['L_it_band_' + str(j_iter + 1)]

            lw_scal = scipy.zeros((int(report['vn'][1]), int(report['hn'][1])))

            # for the fist and last line we have to replicate the top and bottom circle
            for i_iter in range(0, int(report['hn'][1])):
                lw_scal[0, i_iter] = tmp_lw[0].split(',')[0]
                lw_scal[int(report['vn'][1]) - 1, i_iter] = tmp_lw[-1].split(',')[0]

            for i_iter in range(1, int(report['vn'][1]) - 1):
                lw_scal[i_iter, :] = scipy.asarray(tmp_lw[i_iter].split(','), dtype=float)

            # to do, make an array of zeros and loop over each list an apply to eah line.  bruteforce

            f1 = interpolate.interp2d(zenith, azimuth, lw_scal)
            lw[j_iter] = f1(float(param_zenith), float(param_azimuth))

        # ----
        # Now we finally have L_w we calculate the rrs
        # ----

        if parameter == 'rrs':
            tmp_rrs = lw / scipy.asarray(report['Ed_w'], dtype=float)[1:]  # ignore the first val as that is depth of val
        elif parameter == 'Rrs':
            tmp_rrs = lw / scipy.asarray(report['Ed_a'], dtype=float)[1:]  # ignore the first val as that is depth of val

        # make rrs a string so it can be written to file.

        rrs = ",".join(map(str, tmp_rrs))

        return " ," + rrs  # Note could be rrs or Rrs

    def write_batch_report(self, input_directory, parameter):
        """
        Collect all of the batch reports and concatenate the results.  The report should be :

        :param input_directory:
        :param parameter: This is the parameter in which to report.
        """

        # Check to see if there is an @ in the parameter.  If there is split
        if '@' in parameter:
            parameter_dir = parameter.split('@')[1]
            parameter = parameter.split('@')[0]

        # --------------------------------------------------#
        # we put the batch report one directory up in the tree
        # --------------------------------------------------#
        batch_report_file = 'batch_report.txt'
        batch_report_file = os.path.join(input_directory, batch_report_file)
        f = open(batch_report_file, 'w')
        w = csv.writer(f, delimiter=',')

        #--------------------------------------------------#
        # Read in the report from planarrad and pull out the parameter that we want
        #--------------------------------------------------#
        dir_list = os.listdir(input_directory)

        #--------------------------------------------------#
        # Sometimes the report isn't generated for some reason.
        # this checks to see if the first file in the dir list exists and skips if it doesn't
        #--------------------------------------------------#
        read_first_file = True
        i_iter = 0
        while read_first_file:
            if os.path.exists(os.path.join(input_directory, os.path.join(dir_list[i_iter], 'report.txt'))):
                report = self.read_pr_report(
                    os.path.join(input_directory, os.path.join(dir_list[i_iter], 'report.txt')))
                read_first_file = False
            else:
                lg.warning('Missing report file in' + dir_list[i_iter])
                i_iter += 1

        try:
            wave_val = report['band_centres']
            param_val = report[parameter]
        except:
            lg.exception('Parameter :: ' + str(parameter) + ' :: Not in report')

        wave_str = str(wave_val)
        wave_str = wave_str.strip('[').strip(']').replace('\'', '').replace('\\n', '').replace('  ', '').replace(' -,',
                                                                                                                 '').replace(
            ',', '\",\"')

        f.write(
            '\"Sun Azimuth (deg)\",\"Sun Zenith (deg)\",\"Phytoplankton\",\"Scattering X\",\"Scattering Y\",\"CDOM G\",\"CDOM S\",\"Depth (m)\",\"#wave length (nm) ->\",\"' + wave_str + '\"\n')

        #--------------------------------------------------#
        # Get all of the directories under the batch directories
        # The directory names have the IOP parameters in the names
        #--------------------------------------------------#

        for dir in dir_list:
            if os.path.isdir(os.path.abspath(os.path.join(input_directory, dir))):
                tmp_str_list = dir.split('_')
                #for tmp_str in tmp_str_list:
                saa = ''.join(c for c in tmp_str_list[0] if not c.isalpha())
                sza = ''.join(c for c in tmp_str_list[1] if not c.isalpha())
                p = ''.join(c for c in tmp_str_list[2] if not c.isalpha())
                x = ''.join(c for c in tmp_str_list[3] if not c.isalpha())
                y = ''.join(c for c in tmp_str_list[4] if not c.isalpha())
                g = ''.join(c for c in tmp_str_list[5] if not c.isalpha())
                s = ''.join(c for c in tmp_str_list[6] if not c.isalpha())
                z = ''.join(c for c in tmp_str_list[7] if not c.isalpha())

                #--------------------------------------------------#
                # Write the report header and then the values above in the columns
                #--------------------------------------------------#
                try:
                    f.write(saa + ',' + sza + ',' + p + ',' + x + ',' + y + ',' + g + ',' + s + ',' + z + ',')

                    report = self.read_pr_report(os.path.join(input_directory, os.path.join(dir, 'report.txt')))
                    try:
                        # check to see if the parameter has the @ parameter.  If it does pass to directional calculator
                        if 'parameter_dir' in locals():
                            param_val = self.calc_directional_aop(report, parameter, parameter_dir)
                        else:
                            param_val = report[parameter]

                        param_str = str(param_val)
                        param_str = param_str.strip('[').strip(']').replace('\'', '').replace('\\n', '').replace('  ',
                                                                                                                 '')
                        f.write(param_str + '\n')
                    except:
                        lg.exception('Parameter :: ' + str(parameter) + ' :: Not in report')
                except:
                    lg.warning('Cannot find a report in directory :: ' + dir)



from distutils.core import setup

setup(
    name='planarradpy',
    version='0.0.1-4',
    packages=['planarradpy', 'planarradpy.gui', 'planarradpy.log', 'planarradpy.docs', 'planarradpy.tests', 'planarradpy.inputs',
              'planarradpy.inputs.iop_files', 'planarradpy.inputs.sky_files', 'planarradpy.inputs.phase_files',
              'planarradpy.inputs.bottom_files', 'planarradpy.inputs.surface_files', 'planarradpy.outputs',
              'planarradpy.scripts', 'planarradpy.libplanarradpy'],
    url='https://marrabld.github.io/planarradpy/',
    license='GPL',
    scripts=['planarradpy/planarrad.run'],
    include_package_data=True,
    author='Dan Marrable',
    author_email='marrabld+planarradpy@gmail.com',
    description='Tool for batch running PlanarRad across multiple CPUs', requires=['PyQt4'],
)
